"""
Created on 10 Feb 2023
Stream tests for pygpsclient.spartnreader

@author: semuadmin
"""

import os
import sys
import unittest
from io import StringIO
from datetime import datetime

from pyspartn.exceptions import SPARTNMessageError, SPARTNParseError, ParameterError
from pyspartn.spartnreader import SPARTNReader, SPARTNMessage
from pyspartn.spartntypes_core import ERRRAISE, ERRIGNORE, ERRLOG

SPARTN_KEY = "930d847b779b126863c8b3b2766ae7cc"
SPARTN_BASEDATE = datetime(2024, 4, 18, 20, 48, 29, 977255)


class StreamTest(unittest.TestCase):
    def setUp(self):
        self.maxDiff = None
        self.dirname = os.path.dirname(__file__)
        self.streamSPARTN = open(os.path.join(self.dirname, "spartn_mqtt.log"), "rb")
        self.streamBADCRC = open(os.path.join(self.dirname, "spartn_badcrc.log"), "rb")
        self.streamBADPRE = open(
            os.path.join(self.dirname, "spartn_badpreamble.log"), "rb"
        )
        self.spartntransport = b"s\x00\x12\xe2\x00|\x10[\x12H\xf5\t\xa0\xb4+\x99\x02\x15\xe2\x05\x85\xb7\x83\xc5\xfd\x0f\xfe\xdf\x18\xbe\x7fv \xc3`\x82\x98\x10\x07\xdc\xeb\x82\x7f\xcf\xf8\x9e\xa3ta\xad"
        self.spartnbadcrc = b"s\x00\x12\xe2\x00|\x10[\x12H\xf5\t\xa0\xb4+\x99\x02\x15\xe2\x05\x85\xb7\x83\xc5\xfd\x0f\xfe\xdf\x18\xbe\x7fv \xc3`\x82\x98\x10\x07\xdc\xeb\x82\x7f\xcf\xf8\x9e\xa3ta\xa1"
        self.badpayload = b"x\x00\x12\xe2\x00|\x10[\x12H\xf5\t\xa0\xb4+\x99\x02\x15"

    def tearDown(self):
        self.streamSPARTN.close()
        self.streamBADCRC.close()
        self.streamBADPRE.close()

    def catchio(self):
        """
        Capture stdout as string.
        """

        self._saved_stdout = sys.stdout
        self._strout = StringIO()
        sys.stdout = self._strout

    def restoreio(self) -> str:
        """
        Return captured output and restore stdout.
        """

        sys.stdout = self._saved_stdout
        return self._strout.getvalue().strip()

    def testSerialize(self):  # test serialize()
        msg1 = SPARTNReader.parse(self.spartntransport, decode=False)
        msg2 = SPARTNMessage(transport=self.spartntransport)
        res = msg1.serialize()
        self.assertEqual(res, self.spartntransport)
        res1 = msg2.serialize()
        self.assertEqual(res1, self.spartntransport)

    def testsetattr(self):  # test immutability
        EXPECTED_ERROR = (
            "Object is immutable. Updates to eaf not permitted after initialisation."
        )
        with self.assertRaisesRegex(SPARTNMessageError, EXPECTED_ERROR):
            msg = SPARTNReader.parse(self.spartntransport)
            msg.eaf = 0

    def testrepr(self):  # test repr, check eval recreates original object
        EXPECTED_RESULT = "SPARTNMessage(transport=b's\\x00\\x12\\xe2\\x00|\\x10[\\x12H\\xf5\\t\\xa0\\xb4+\\x99\\x02\\x15\\xe2\\x05\\x85\\xb7\\x83\\xc5\\xfd\\x0f\\xfe\\xdf\\x18\\xbe\\x7fv \\xc3`\\x82\\x98\\x10\\x07\\xdc\\xeb\\x82\\x7f\\xcf\\xf8\\x9e\\xa3ta\\xad')"
        msg1 = SPARTNReader.parse(self.spartntransport, decode=False)
        self.assertEqual(repr(msg1), EXPECTED_RESULT)
        msg2 = eval(repr(msg1))
        self.assertEqual(str(msg1), str(msg2))

    def testpayload(self):  # test payload
        EXPECTED_RESULT = b"\xf5\x09\xa0\xb4\x2b\x99\x02\x15\xe2\x05\x85\xb7\x83\xc5\xfd\x0f\xfe\xdf\x18\xbe\x7f\x76\x20\xc3\x60\x82\x98\x10\x07\xdc\xeb\x82\x7f\xcf\xf8\x9e\xa3"
        msg = SPARTNReader.parse(self.spartntransport)
        # print(msg)
        self.assertEqual(msg.payload, EXPECTED_RESULT)
        self.assertEqual(msg.nData, len(msg.payload))

    def testnopayload(self):  # test null payload
        EXPECTED_ERROR = "Transport must be provided"
        with self.assertRaisesRegex(SPARTNMessageError, EXPECTED_ERROR):
            msg = SPARTNMessage(transport=None)

    def testbadpayload2(self):  # test null payload
        EXPECTED_ERROR = "Unknown message preamble 120"
        with self.assertRaisesRegex(SPARTNParseError, EXPECTED_ERROR):
            msg = SPARTNMessage(transport=self.badpayload)

    def testbadpayload(self):  # test null payload
        EXPECTED_ERROR = "Unknown message preamble 120"
        with self.assertRaisesRegex(SPARTNParseError, EXPECTED_ERROR):
            msg = SPARTNReader.parse(self.badpayload)

    def testbadcrc(self):  # test bad CRC
        EXPECTED_ERROR = "Invalid CRC 7627169"
        with self.assertRaisesRegex(SPARTNMessageError, EXPECTED_ERROR):
            msg = SPARTNReader.parse(self.spartnbadcrc)

    def testERRRAISE(self):  # test stream of SPARTN messages with quitonerror = 2
        EXPECTED_ERROR = "Invalid CRC 15632804"
        with self.assertRaisesRegex(SPARTNParseError, EXPECTED_ERROR):
            spr = SPARTNReader(self.streamBADCRC, quitonerror=ERRRAISE)
            for raw, parsed in spr:
                pass

    def testERRRAISE2(self):  # test stream of SPARTN messages with quitonerror = 2
        EXPECTED_ERROR = "Unknown protocol b'\xaa'"
        with self.assertRaises(SPARTNParseError):
            spr = SPARTNReader(self.streamBADPRE, quitonerror=ERRRAISE)
            for raw, parsed in spr:
                pass

    def testERRLOG(self):  # test stream of SPARTN messages with quitonerror = 1
        EXPECTED_OUTPUT = "Invalid CRC 15632804"
        self.catchio()
        spr = SPARTNReader(self.streamBADCRC, quitonerror=ERRLOG)
        for raw, parsed in spr:
            pass
        output = self.restoreio()
        self.assertEqual(output, EXPECTED_OUTPUT)

    def testERRIGNORE(self):  # test stream of SPARTN messages with quitonerror = 1
        EXPECTED_OUTPUT = ""
        self.catchio()
        spr = SPARTNReader(self.streamBADCRC, quitonerror=ERRIGNORE)
        for raw, parsed in spr:
            pass
        output = self.restoreio()
        self.assertEqual(output, EXPECTED_OUTPUT)

    def testERRHandler(self):  # test stream of SPARTN messages with quitonerror = 1
        def igor(err):
            print(f"The error was ({err})")

        EXPECTED_OUTPUT = "The error was (Invalid CRC 15632804)"
        self.catchio()
        spr = SPARTNReader(self.streamBADCRC, quitonerror=ERRLOG, errorhandler=igor)
        for raw, parsed in spr:
            pass
        output = self.restoreio()
        self.assertEqual(output, EXPECTED_OUTPUT)

    def testHPACLOG(
        self,
    ):  # test decoding of SPARTN HPAC message
        EXPECTED_RESULT = [
            "<SPARTN(SPARTN-1X-HPAC-GPS, msgType=1, nData=495, eaf=1, crcType=2, frameCrc=11, msgSubtype=0, timeTagtype=1, gnssTimeTag=451165680, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=30, authInd=1, embAuthLen=0, crc=7977429, SF005=152, SF068=1, SF069=0, SF030=9, SF031_01=0, SF039_01=0, SF040T_01=1, SF040I_01=1, SF041_01=1, SF042_01=1, SF043_01=127, SF044_01=1, SF048_01=202, SF049a_01=255, SF049b_01=256, SF054_01=1, SatBitmaskLen_01=0, SF011_01=880836738, SF055_01_01=1, SF056_01_01=1, SF060_01_01=7913, SF061a_01_01=8079, SF061b_01_01=8172, SF055_01_02=1, SF056_01_02=1, SF060_01_02=8141, SF061a_01_02=8270, SF061b_01_02=8186, SF055_01_03=3, SF056_01_03=1, SF060_01_03=8149, SF061a_01_03=8236, SF061b_01_03=8207, SF055_01_04=3, SF056_01_04=1, SF060_01_04=8877, SF061a_01_04=8250, SF061b_01_04=8221, SF055_01_05=5, SF056_01_05=1, SF060_01_05=8805, SF061a_01_05=8274, SF061b_01_05=8217, SF055_01_06=5, SF056_01_06=1, SF060_01_06=8603, SF061a_01_06=8074, SF061b_01_06=8162, SF055_01_07=4, SF056_01_07=1, SF060_01_07=7975, SF061a_01_07=7957, SF061b_01_07=8160, SF031_02=1, SF039_02=0, SF040T_02=1, SF040I_02=1, SF041_02=1, SF042_02=1, SF043_02=127, SF044_02=1, SF048_02=202, SF049a_02=253, SF049b_02=255, SF054_02=1, SatBitmaskLen_02=0, SF011_02=880836738, SF055_02_01=1, SF056_02_01=1, SF060_02_01=7963, SF061a_02_01=8205, SF061b_02_01=8173, SF055_02_02=1, SF056_02_02=1, SF060_02_02=8108, SF061a_02_02=8235, SF061b_02_02=8183, SF055_02_03=3, SF056_02_03=1, SF060_02_03=8161, SF061a_02_03=8087, SF061b_02_03=8198, SF055_02_04=4, SF056_02_04=1, SF060_02_04=8789, SF061a_02_04=8272, SF061b_02_04=8254, SF055_02_05=5, SF056_02_05=1, SF060_02_05=8708, SF061a_02_05=8169, SF061b_02_05=8251, SF055_02_06=6, SF056_02_06=1, SF060_02_06=8564, SF061a_02_06=8293, SF061b_02_06=8320, SF055_02_07=4, SF056_02_07=1, SF060_02_07=8144, SF061a_02_07=8048, SF061b_02_07=8155, SF031_03=2, SF039_03=0, SF040T_03=1, SF040I_03=1, SF041_03=1, SF042_03=1, SF043_03=127, SF044_03=1, SF048_03=201, SF049a_03=258, SF049b_03=254, SF054_03=1, SatBitmaskLen_03=0, SF011_03=880836738, SF055_03_01=2, SF056_03_01=1, SF060_03_01=7932, SF061a_03_01=8206, SF061b_03_01=8179, SF055_03_02=2, SF056_03_02=1, SF060_03_02=8102, SF061a_03_02=8221, SF061b_03_02=8192, SF055_03_03=2, SF056_03_03=1, SF060_03_03=8169, SF061a_03_03=8089, SF061b_03_03=8201, SF055_03_04=2, SF056_03_04=1, SF060_03_04=8851, SF061a_03_04=8263, SF061b_03_04=8223, SF055_03_05=4, SF056_03_05=1, SF060_03_05=8817, SF061a_03_05=8163, SF061b_03_05=8239, SF055_03_06=6, SF056_03_06=1, SF060_03_06=8581, SF061a_03_06=8185, SF061b_03_06=8151, SF055_03_07=4, SF056_03_07=1, SF060_03_07=8078, SF061a_03_07=8071, SF061b_03_07=8157, SF031_04=3, SF039_04=0, SF040T_04=1, SF040I_04=1, SF041_04=1, SF042_04=1, SF043_04=127, SF044_04=1, SF048_04=203, SF049a_04=253, SF049b_04=255, SF054_04=1, SatBitmaskLen_04=0, SF011_04=880836610, SF055_04_01=1, SF056_04_01=1, SF060_04_01=7973, SF061a_04_01=8206, SF061b_04_01=8177, SF055_04_02=1, SF056_04_02=1, SF060_04_02=8097, SF061a_04_02=8226, SF061b_04_02=8186, SF055_04_03=4, SF056_04_03=1, SF060_04_03=8201, SF061a_04_03=8157, SF061b_04_03=8196, SF055_04_04=4, SF056_04_04=1, SF060_04_04=8712, SF061a_04_04=8234, SF061b_04_04=8253, SF055_04_05=4, SF056_04_05=1, SF060_04_05=8633, SF061a_04_05=8150, SF061b_04_05=8254, SF055_04_06=1, SF056_04_06=1, SF060_04_06=8219, SF061a_04_06=8141, SF061b_04_06=8150, SF031_05=4, SF039_05=0, SF040T_05=1, SF040I_05=1, SF041_05=1, SF042_05=1, SF043_05=127, SF044_05=1, SF048_05=203, SF049a_05=252, SF049b_05=256, SF054_05=1, SatBitmaskLen_05=0, SF011_05=880836610, SF055_05_01=2, SF056_05_01=1, SF060_05_01=7932, SF061a_05_01=8245, SF061b_05_01=8181, SF055_05_02=3, SF056_05_02=1, SF060_05_02=8079, SF061a_05_02=8211, SF061b_05_02=8187, SF055_05_03=2, SF056_05_03=1, SF060_05_03=8257, SF061a_05_03=8099, SF061b_05_03=8209, SF055_05_04=3, SF056_05_04=1, SF060_05_04=8827, SF061a_05_04=8270, SF061b_05_04=8217, SF055_05_05=3, SF056_05_05=1, SF060_05_05=8839, SF061a_05_05=8144, SF061b_05_05=8238, SF055_05_06=3, SF056_05_06=1, SF060_05_06=8100, SF061a_05_06=8221, SF061b_05_06=8146, SF031_06=5, SF039_06=0, SF040T_06=1, SF040I_06=1, SF041_06=1, SF042_06=1, SF043_06=127, SF044_06=1, SF048_06=209, SF049a_06=248, SF049b_06=251, SF054_06=1, SatBitmaskLen_06=0, SF011_06=880836610, SF055_06_01=2, SF056_06_01=1, SF060_06_01=8109, SF061a_06_01=8165, SF061b_06_01=8162, SF055_06_02=4, SF056_06_02=1, SF060_06_02=8202, SF061a_06_02=8183, SF061b_06_02=8187, SF055_06_03=3, SF056_06_03=1, SF060_06_03=8317, SF061a_06_03=8168, SF061b_06_03=8190, SF055_06_04=3, SF056_06_04=1, SF060_06_04=8783, SF061a_06_04=8197, SF061b_06_04=8180, SF055_06_05=4, SF056_06_05=1, SF060_06_05=8755, SF061a_06_05=8123, SF061b_06_05=8208, SF055_06_06=2, SF056_06_06=1, SF060_06_06=8404, SF061a_06_06=8130, SF061b_06_06=8122, SF031_07=6, SF039_07=0, SF040T_07=1, SF040I_07=1, SF041_07=1, SF042_07=1, SF043_07=128, SF044_07=1, SF048_07=206, SF049a_07=253, SF049b_07=257, SF054_07=1, SatBitmaskLen_07=0, SF011_07=880836610, SF055_07_01=2, SF056_07_01=1, SF060_07_01=8050, SF061a_07_01=8184, SF061b_07_01=8147, SF055_07_02=2, SF056_07_02=1, SF060_07_02=8170, SF061a_07_02=8157, SF061b_07_02=8144, SF055_07_03=2, SF056_07_03=1, SF060_07_03=8363, SF061a_07_03=8090, SF061b_07_03=8208, SF055_07_04=3, SF056_07_04=1, SF060_07_04=8789, SF061a_07_04=8235, SF061b_07_04=8188, SF055_07_05=2, SF056_07_05=1, SF060_07_05=8801, SF061a_07_05=8137, SF061b_07_05=8255, SF055_07_06=1, SF056_07_06=1, SF060_07_06=8304, SF061a_07_06=8144, SF061b_07_06=8112, SF031_08=7, SF039_08=0, SF040T_08=1, SF040I_08=1, SF041_08=1, SF042_08=1, SF043_08=127, SF044_08=1, SF048_08=204, SF049a_08=250, SF049b_08=254, SF054_08=1, SatBitmaskLen_08=0, SF011_08=880836610, SF055_08_01=5, SF056_08_01=1, SF060_08_01=7983, SF061a_08_01=8123, SF061b_08_01=8192, SF055_08_02=3, SF056_08_02=1, SF060_08_02=8125, SF061a_08_02=8127, SF061b_08_02=8213, SF055_08_03=2, SF056_08_03=1, SF060_08_03=8380, SF061a_08_03=8056, SF061b_08_03=8231, SF055_08_04=3, SF056_08_04=1, SF060_08_04=8833, SF061a_08_04=8220, SF061b_08_04=8228, SF055_08_05=4, SF056_08_05=1, SF060_08_05=8909, SF061a_08_05=8149, SF061b_08_05=8284, SF055_08_06=4, SF056_08_06=1, SF060_08_06=8168, SF061a_08_06=8153, SF061b_08_06=8142, SF031_09=8, SF039_09=0, SF040T_09=1, SF040I_09=1, SF041_09=1, SF042_09=1, SF043_09=128, SF044_09=1, SF048_09=219, SF049a_09=246, SF049b_09=249, SF054_09=1, SatBitmaskLen_09=0, SF011_09=880836610, SF055_09_01=2, SF056_09_01=1, SF060_09_01=8208, SF061a_09_01=8024, SF061b_09_01=8184, SF055_09_02=2, SF056_09_02=1, SF060_09_02=8265, SF061a_09_02=8076, SF061b_09_02=8218, SF055_09_03=2, SF056_09_03=1, SF060_09_03=8346, SF061a_09_03=8036, SF061b_09_03=8201, SF055_09_04=1, SF056_09_04=1, SF060_09_04=8691, SF061a_09_04=8093, SF061b_09_04=8214, SF055_09_05=3, SF056_09_05=1, SF060_09_05=8634, SF061a_09_05=8075, SF061b_09_05=8219, SF055_09_06=2, SF056_09_06=1, SF060_09_06=8616, SF061a_09_06=7920, SF061b_09_06=8142, SF031_10=9, SF039_10=0, SF040T_10=1, SF040I_10=1, SF041_10=1, SF042_10=2, SF043_10=128, SF044_10=1, SF048_10=208, SF049a_10=253, SF049b_10=252, SF054_10=1, SatBitmaskLen_10=0, SF011_10=880836610, SF055_10_01=1, SF056_10_01=1, SF060_10_01=8081, SF061a_10_01=8087, SF061b_10_01=8126, SF055_10_02=2, SF056_10_02=1, SF060_10_02=8180, SF061a_10_02=8109, SF061b_10_02=8154, SF055_10_03=3, SF056_10_03=1, SF060_10_03=8415, SF061a_10_03=8011, SF061b_10_03=8209, SF055_10_04=2, SF056_10_04=1, SF060_10_04=8740, SF061a_10_04=8212, SF061b_10_04=8186, SF055_10_05=4, SF056_10_05=1, SF060_10_05=8785, SF061a_10_05=8157, SF061b_10_05=8214, SF055_10_06=2, SF056_10_06=1, SF060_10_06=8382, SF061a_10_06=8018, SF061b_10_06=8092)>",
            "<SPARTN(SPARTN-1X-HPAC-GPS, msgType=1, nData=478, eaf=1, crcType=2, frameCrc=14, msgSubtype=0, timeTagtype=1, gnssTimeTag=451165680, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=31, authInd=1, embAuthLen=0, crc=8969842, SF005=152, SF068=1, SF069=0, SF030=9, SF031_01=10, SF039_01=0, SF040T_01=1, SF040I_01=1, SF041_01=1, SF042_01=1, SF043_01=128, SF044_01=1, SF048_01=207, SF049a_01=252, SF049b_01=255, SF054_01=1, SatBitmaskLen_01=0, SF011_01=880836610, SF055_01_01=2, SF056_01_01=1, SF060_01_01=8034, SF061a_01_01=8123, SF061b_01_01=8191, SF055_01_02=2, SF056_01_02=1, SF060_01_02=8157, SF061a_01_02=8153, SF061b_01_02=8218, SF055_01_03=2, SF056_01_03=1, SF060_01_03=8474, SF061a_01_03=8038, SF061b_01_03=8229, SF055_01_04=2, SF056_01_04=1, SF060_01_04=8808, SF061a_01_04=8211, SF061b_01_04=8238, SF055_01_05=3, SF056_01_05=1, SF060_01_05=8912, SF061a_01_05=8149, SF061b_01_05=8303, SF055_01_06=3, SF056_01_06=1, SF060_01_06=8254, SF061a_01_06=8055, SF061b_01_06=8169, SF031_02=11, SF039_02=0, SF040T_02=1, SF040I_02=1, SF041_02=1, SF042_02=2, SF043_02=129, SF044_02=1, SF048_02=230, SF049a_02=250, SF049b_02=254, SF054_02=1, SatBitmaskLen_02=0, SF011_02=880836610, SF055_02_01=2, SF056_02_01=1, SF060_02_01=8345, SF061a_02_01=8037, SF061b_02_01=8187, SF055_02_02=1, SF056_02_02=1, SF060_02_02=8356, SF061a_02_02=8070, SF061b_02_02=8199, SF055_02_03=1, SF056_02_03=1, SF060_02_03=8475, SF061a_02_03=8035, SF061b_02_03=8178, SF055_02_04=3, SF056_02_04=1, SF060_02_04=8750, SF061a_02_04=8132, SF061b_02_04=8201, SF055_02_05=2, SF056_02_05=1, SF060_02_05=8702, SF061a_02_05=8078, SF061b_02_05=8245, SF055_02_06=1, SF056_02_06=1, SF060_02_06=8874, SF061a_02_06=7927, SF061b_02_06=8148, SF031_03=12, SF039_03=0, SF040T_03=1, SF040I_03=1, SF041_03=1, SF042_03=2, SF043_03=129, SF044_03=1, SF048_03=228, SF049a_03=244, SF049b_03=254, SF054_03=1, SatBitmaskLen_03=0, SF011_03=880836610, SF055_03_01=1, SF056_03_01=1, SF060_03_01=8330, SF061a_03_01=8041, SF061b_03_01=8174, SF055_03_02=1, SF056_03_02=1, SF060_03_02=8369, SF061a_03_02=8084, SF061b_03_02=8201, SF055_03_03=2, SF056_03_03=1, SF060_03_03=8504, SF061a_03_03=8007, SF061b_03_03=8247, SF055_03_04=1, SF056_03_04=1, SF060_03_04=8767, SF061a_03_04=8141, SF061b_03_04=8210, SF055_03_05=1, SF056_03_05=1, SF060_03_05=8761, SF061a_03_05=8072, SF061b_03_05=8228, SF055_03_06=2, SF056_03_06=1, SF060_03_06=8786, SF061a_03_06=7950, SF061b_03_06=8112, SF031_04=13, SF039_04=0, SF040T_04=1, SF040I_04=1, SF041_04=1, SF042_04=2, SF043_04=129, SF044_04=1, SF048_04=210, SF049a_04=249, SF049b_04=252, SF054_04=1, SatBitmaskLen_04=0, SF011_04=880836610, SF055_04_01=1, SF056_04_01=1, SF060_04_01=8212, SF061a_04_01=8107, SF061b_04_01=8127, SF055_04_02=2, SF056_04_02=1, SF060_04_02=8274, SF061a_04_02=8148, SF061b_04_02=8136, SF055_04_03=3, SF056_04_03=1, SF060_04_03=8539, SF061a_04_03=7995, SF061b_04_03=8192, SF055_04_04=4, SF056_04_04=1, SF060_04_04=8722, SF061a_04_04=8217, SF061b_04_04=8174, SF055_04_05=1, SF056_04_05=1, SF060_04_05=8781, SF061a_04_05=8164, SF061b_04_05=8199, SF055_04_06=2, SF056_04_06=1, SF060_04_06=8602, SF061a_04_06=8010, SF061b_04_06=8099, SF031_05=14, SF039_05=0, SF040T_05=1, SF040I_05=1, SF041_05=1, SF042_05=1, SF043_05=129, SF044_05=1, SF048_05=210, SF049a_05=250, SF049b_05=256, SF054_05=1, SatBitmaskLen_05=0, SF011_05=880836610, SF055_05_01=1, SF056_05_01=1, SF060_05_01=8140, SF061a_05_01=8091, SF061b_05_01=8132, SF055_05_02=1, SF056_05_02=1, SF060_05_02=8222, SF061a_05_02=8121, SF061b_05_02=8149, SF055_05_03=1, SF056_05_03=1, SF060_05_03=8539, SF061a_05_03=8005, SF061b_05_03=8186, SF055_05_04=2, SF056_05_04=1, SF060_05_04=8721, SF061a_05_04=8235, SF061b_05_04=8203, SF055_05_05=1, SF056_05_05=1, SF060_05_05=8808, SF061a_05_05=8163, SF061b_05_05=8221, SF055_05_06=2, SF056_05_06=1, SF060_05_06=8482, SF061a_05_06=8020, SF061b_05_06=8085, SF031_06=15, SF039_06=0, SF040T_06=1, SF040I_06=1, SF041_06=1, SF042_06=1, SF043_06=129, SF044_06=1, SF048_06=205, SF049a_06=252, SF049b_06=253, SF054_06=1, SatBitmaskLen_06=0, SF011_06=880836610, SF055_06_01=1, SF056_06_01=1, SF060_06_01=8064, SF061a_06_01=8227, SF061b_06_01=8126, SF055_06_02=1, SF056_06_02=1, SF060_06_02=8166, SF061a_06_02=8254, SF061b_06_02=8141, SF055_06_03=4, SF056_06_03=1, SF060_06_03=8553, SF061a_06_03=8117, SF061b_06_03=8185, SF055_06_04=2, SF056_06_04=1, SF060_06_04=8736, SF061a_06_04=8355, SF061b_06_04=8199, SF055_06_05=4, SF056_06_05=1, SF060_06_05=8864, SF061a_06_05=8302, SF061b_06_05=8222, SF055_06_06=1, SF056_06_06=1, SF060_06_06=8341, SF061a_06_06=8199, SF061b_06_06=8084, SF031_07=16, SF039_07=0, SF040T_07=1, SF040I_07=1, SF041_07=1, SF042_07=1, SF043_07=129, SF044_07=1, SF048_07=221, SF049a_07=267, SF049b_07=253, SF054_07=1, SatBitmaskLen_07=0, SF011_07=880836610, SF055_07_01=1, SF056_07_01=1, SF060_07_01=8457, SF061a_07_01=8142, SF061b_07_01=8145, SF055_07_02=1, SF056_07_02=1, SF060_07_02=8462, SF061a_07_02=8181, SF061b_07_02=8160, SF055_07_03=1, SF056_07_03=1, SF060_07_03=8649, SF061a_07_03=8050, SF061b_07_03=8219, SF055_07_04=1, SF056_07_04=1, SF060_07_04=8826, SF061a_07_04=8232, SF061b_07_04=8172, SF055_07_05=1, SF056_07_05=1, SF060_07_05=8842, SF061a_07_05=8182, SF061b_07_05=8193, SF055_07_06=2, SF056_07_06=1, SF060_07_06=8984, SF061a_07_06=8024, SF061b_07_06=8077, SF031_08=17, SF039_08=0, SF040T_08=1, SF040I_08=1, SF041_08=1, SF042_08=1, SF043_08=129, SF044_08=1, SF048_08=214, SF049a_08=264, SF049b_08=249, SF054_08=1, SatBitmaskLen_08=0, SF011_08=880836610, SF055_08_01=1, SF056_08_01=1, SF060_08_01=8383, SF061a_08_01=8144, SF061b_08_01=8130, SF055_08_02=1, SF056_08_02=1, SF060_08_02=8414, SF061a_08_02=8192, SF061b_08_02=8148, SF055_08_03=2, SF056_08_03=1, SF060_08_03=8703, SF061a_08_03=8042, SF061b_08_03=8237, SF055_08_04=1, SF056_08_04=1, SF060_08_04=8808, SF061a_08_04=8233, SF061b_08_04=8182, SF055_08_05=2, SF056_08_05=1, SF060_08_05=8864, SF061a_08_05=8200, SF061b_08_05=8218, SF055_08_06=1, SF056_08_06=1, SF060_08_06=8844, SF061a_08_06=8050, SF061b_08_06=8091, SF031_09=18, SF039_09=0, SF040T_09=1, SF040I_09=1, SF041_09=1, SF042_09=1, SF043_09=129, SF044_09=1, SF048_09=210, SF049a_09=245, SF049b_09=253, SF054_09=1, SatBitmaskLen_09=0, SF011_09=880836610, SF055_09_01=1, SF056_09_01=1, SF060_09_01=8267, SF061a_09_01=8164, SF061b_09_01=8173, SF055_09_02=2, SF056_09_02=1, SF060_09_02=8323, SF061a_09_02=8209, SF061b_09_02=8194, SF055_09_03=4, SF056_09_03=1, SF060_09_03=8693, SF061a_09_03=8026, SF061b_09_03=8263, SF055_09_04=1, SF056_09_04=1, SF060_09_04=8754, SF061a_09_04=8274, SF061b_09_04=8217, SF055_09_05=2, SF056_09_05=1, SF060_09_05=8853, SF061a_09_05=8229, SF061b_09_05=8248, SF055_09_06=1, SF056_09_06=1, SF060_09_06=8659, SF061a_09_06=8125, SF061b_09_06=8121, SF031_10=19, SF039_10=0, SF040T_10=1, SF040I_10=1, SF041_10=1, SF042_10=1, SF043_10=129, SF044_10=1, SF048_10=206, SF049a_10=255, SF049b_10=252, SF054_10=1, SatBitmaskLen_10=0, SF011_10=880836610, SF055_10_01=1, SF056_10_01=1, SF060_10_01=8055, SF061a_10_01=8232, SF061b_10_01=8125, SF055_10_02=1, SF056_10_02=1, SF060_10_02=8141, SF061a_10_02=8257, SF061b_10_02=8144, SF055_10_03=2, SF056_10_03=1, SF060_10_03=8607, SF061a_10_03=8069, SF061b_10_03=8205, SF055_10_04=1, SF056_10_04=1, SF060_10_04=8642, SF061a_10_04=8374, SF061b_10_04=8204, SF055_10_05=1, SF056_10_05=1, SF060_10_05=8790, SF061a_10_05=8343, SF061b_10_05=8217, SF055_10_06=1, SF056_10_06=1, SF060_10_06=8355, SF061a_10_06=8199, SF061b_10_06=8075)>",
            "<SPARTN(SPARTN-1X-HPAC-GPS, msgType=1, nData=478, eaf=1, crcType=2, frameCrc=14, msgSubtype=0, timeTagtype=1, gnssTimeTag=451165680, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=32, authInd=1, embAuthLen=0, crc=114625, SF005=152, SF068=1, SF069=0, SF030=9, SF031_01=20, SF039_01=0, SF040T_01=1, SF040I_01=1, SF041_01=1, SF042_01=3, SF043_01=130, SF044_01=1, SF048_01=216, SF049a_01=255, SF049b_01=255, SF054_01=1, SatBitmaskLen_01=0, SF011_01=880836610, SF055_01_01=1, SF056_01_01=1, SF060_01_01=8467, SF061a_01_01=8156, SF061b_01_01=8135, SF055_01_02=1, SF056_01_02=1, SF060_01_02=8457, SF061a_01_02=8192, SF061b_01_02=8151, SF055_01_03=2, SF056_01_03=1, SF060_01_03=8737, SF061a_01_03=8040, SF061b_01_03=8224, SF055_01_04=1, SF056_01_04=1, SF060_01_04=8801, SF061a_01_04=8229, SF061b_01_04=8173, SF055_01_05=1, SF056_01_05=1, SF060_01_05=8844, SF061a_01_05=8196, SF061b_01_05=8200, SF055_01_06=1, SF056_01_06=1, SF060_01_06=9038, SF061a_01_06=8047, SF061b_01_06=8073, SF031_02=21, SF039_02=0, SF040T_02=1, SF040I_02=1, SF041_02=1, SF042_02=3, SF043_02=130, SF044_02=1, SF048_02=213, SF049a_02=249, SF049b_02=244, SF054_02=1, SatBitmaskLen_02=0, SF011_02=880836610, SF055_02_01=1, SF056_02_01=1, SF060_02_01=8398, SF061a_02_01=8147, SF061b_02_01=8139, SF055_02_02=1, SF056_02_02=1, SF060_02_02=8408, SF061a_02_02=8189, SF061b_02_02=8152, SF055_02_03=3, SF056_02_03=1, SF060_02_03=8780, SF061a_02_03=8064, SF061b_02_03=8220, SF055_02_04=1, SF056_02_04=1, SF060_02_04=8787, SF061a_02_04=8225, SF061b_02_04=8188, SF055_02_05=2, SF056_02_05=1, SF060_02_05=8859, SF061a_02_05=8196, SF061b_02_05=8218, SF055_02_06=1, SF056_02_06=1, SF060_02_06=8893, SF061a_02_06=8077, SF061b_02_06=8077, SF031_03=22, SF039_03=0, SF040T_03=1, SF040I_03=1, SF041_03=1, SF042_03=2, SF043_03=130, SF044_03=1, SF048_03=211, SF049a_03=262, SF049b_03=252, SF054_03=1, SatBitmaskLen_03=0, SF011_03=880836610, SF055_03_01=1, SF056_03_01=1, SF060_03_01=8284, SF061a_03_01=8164, SF061b_03_01=8169, SF055_03_02=1, SF056_03_02=1, SF060_03_02=8316, SF061a_03_02=8203, SF061b_03_02=8191, SF055_03_03=1, SF056_03_03=1, SF060_03_03=8756, SF061a_03_03=8019, SF061b_03_03=8269, SF055_03_04=1, SF056_03_04=1, SF060_03_04=8714, SF061a_03_04=8259, SF061b_03_04=8203, SF055_03_05=2, SF056_03_05=1, SF060_03_05=8831, SF061a_03_05=8213, SF061b_03_05=8232, SF055_03_06=1, SF056_03_06=1, SF060_03_06=8712, SF061a_03_06=8119, SF061b_03_06=8105, SF031_04=23, SF039_04=0, SF040T_04=1, SF040I_04=1, SF041_04=1, SF042_04=3, SF043_04=130, SF044_04=1, SF048_04=206, SF049a_04=244, SF049b_04=250, SF054_04=1, SatBitmaskLen_04=0, SF011_04=880836610, SF055_04_01=1, SF056_04_01=1, SF060_04_01=8264, SF061a_04_01=8172, SF061b_04_01=8180, SF055_04_02=1, SF056_04_02=1, SF060_04_02=8320, SF061a_04_02=8207, SF061b_04_02=8200, SF055_04_03=2, SF056_04_03=1, SF060_04_03=8844, SF061a_04_03=8023, SF061b_04_03=8252, SF055_04_04=1, SF056_04_04=1, SF060_04_04=8735, SF061a_04_04=8273, SF061b_04_04=8222, SF055_04_05=2, SF056_04_05=1, SF060_04_05=8887, SF061a_04_05=8240, SF061b_04_05=8250, SF055_04_06=2, SF056_04_06=1, SF060_04_06=8622, SF061a_04_06=8137, SF061b_04_06=8117, SF031_05=24, SF039_05=0, SF040T_05=1, SF040I_05=1, SF041_05=1, SF042_05=1, SF043_05=130, SF044_05=1, SF048_05=206, SF049a_05=252, SF049b_05=254, SF054_05=1, SatBitmaskLen_05=0, SF011_05=880836610, SF055_05_01=1, SF056_05_01=1, SF060_05_01=8121, SF061a_05_01=8202, SF061b_05_01=8165, SF055_05_02=1, SF056_05_02=1, SF060_05_02=8198, SF061a_05_02=8237, SF061b_05_02=8188, SF055_05_03=1, SF056_05_03=1, SF060_05_03=8774, SF061a_05_03=8095, SF061b_05_03=8243, SF055_05_04=1, SF056_05_04=1, SF060_05_04=8654, SF061a_05_04=8304, SF061b_05_04=8245, SF055_05_05=1, SF056_05_05=1, SF060_05_05=8826, SF061a_05_05=8293, SF061b_05_05=8274, SF055_05_06=1, SF056_05_06=1, SF060_05_06=8417, SF061a_05_06=8186, SF061b_05_06=8100, SF031_06=25, SF039_06=0, SF040T_06=1, SF040I_06=1, SF041_06=1, SF042_06=1, SF043_06=130, SF044_06=1, SF048_06=209, SF049a_06=249, SF049b_06=257, SF054_06=1, SatBitmaskLen_06=0, SF011_06=880836610, SF055_06_01=1, SF056_06_01=1, SF060_06_01=8092, SF061a_06_01=8183, SF061b_06_01=8171, SF055_06_02=1, SF056_06_02=1, SF060_06_02=8182, SF061a_06_02=8211, SF061b_06_02=8185, SF055_06_03=2, SF056_06_03=1, SF060_06_03=8851, SF061a_06_03=8070, SF061b_06_03=8233, SF055_06_04=1, SF056_06_04=1, SF060_06_04=8688, SF061a_06_04=8268, SF061b_06_04=8242, SF055_06_05=1, SF056_06_05=1, SF060_06_05=8890, SF061a_06_05=8308, SF061b_06_05=8270, SF055_06_06=1, SF056_06_06=1, SF060_06_06=8331, SF061a_06_06=8159, SF061b_06_06=8118, SF031_07=26, SF039_07=0, SF040T_07=1, SF040I_07=1, SF041_07=1, SF042_07=3, SF043_07=131, SF044_07=1, SF048_07=212, SF049a_07=256, SF049b_07=248, SF054_07=1, SatBitmaskLen_07=0, SF011_07=880836610, SF055_07_01=1, SF056_07_01=1, SF060_07_01=8460, SF061a_07_01=8172, SF061b_07_01=8057, SF055_07_02=1, SF056_07_02=1, SF060_07_02=8387, SF061a_07_02=8222, SF061b_07_02=8088, SF055_07_03=2, SF056_07_03=1, SF060_07_03=8737, SF061a_07_03=8066, SF061b_07_03=8189, SF055_07_04=1, SF056_07_04=1, SF060_07_04=8661, SF061a_07_04=8298, SF061b_07_04=8136, SF055_07_05=2, SF056_07_05=1, SF060_07_05=8697, SF061a_07_05=8269, SF061b_07_05=8164, SF055_07_06=2, SF056_07_06=1, SF060_07_06=9174, SF061a_07_06=8121, SF061b_07_06=7996, SF031_08=27, SF039_08=0, SF040T_08=1, SF040I_08=1, SF041_08=1, SF042_08=2, SF043_08=131, SF044_08=1, SF048_08=207, SF049a_08=258, SF049b_08=260, SF054_08=1, SatBitmaskLen_08=0, SF011_08=880836610, SF055_08_01=1, SF056_08_01=1, SF060_08_01=8352, SF061a_08_01=8222, SF061b_08_01=8098, SF055_08_02=2, SF056_08_02=1, SF060_08_02=8320, SF061a_08_02=8257, SF061b_08_02=8123, SF055_08_03=2, SF056_08_03=1, SF060_08_03=8736, SF061a_08_03=8100, SF061b_08_03=8202, SF055_08_04=1, SF056_08_04=1, SF060_08_04=8645, SF061a_08_04=8278, SF061b_08_04=8145, SF055_08_05=2, SF056_08_05=1, SF060_08_05=8716, SF061a_08_05=8266, SF061b_08_05=8177, SF055_08_06=2, SF056_08_06=1, SF060_08_06=8972, SF061a_08_06=8175, SF061b_08_06=8019, SF031_09=28, SF039_09=0, SF040T_09=1, SF040I_09=1, SF041_09=1, SF042_09=2, SF043_09=130, SF044_09=1, SF048_09=208, SF049a_09=247, SF049b_09=257, SF054_09=1, SatBitmaskLen_09=0, SF011_09=880836610, SF055_09_01=1, SF056_09_01=1, SF060_09_01=8287, SF061a_09_01=8242, SF061b_09_01=8117, SF055_09_02=1, SF056_09_02=1, SF060_09_02=8272, SF061a_09_02=8272, SF061b_09_02=8127, SF055_09_03=2, SF056_09_03=1, SF060_09_03=8745, SF061a_09_03=8140, SF061b_09_03=8189, SF055_09_04=2, SF056_09_04=1, SF060_09_04=8624, SF061a_09_04=8291, SF061b_09_04=8175, SF055_09_05=2, SF056_09_05=1, SF060_09_05=8712, SF061a_09_05=8268, SF061b_09_05=8188, SF055_09_06=1, SF056_09_06=1, SF060_09_06=8837, SF061a_09_06=8204, SF061b_09_06=8031, SF031_10=29, SF039_10=0, SF040T_10=1, SF040I_10=1, SF041_10=1, SF042_10=4, SF043_10=130, SF044_10=1, SF048_10=208, SF049a_10=301, SF049b_10=257, SF054_10=1, SatBitmaskLen_10=0, SF011_10=880836610, SF055_10_01=2, SF056_10_01=1, SF060_10_01=8289, SF061a_10_01=8271, SF061b_10_01=8107, SF055_10_02=1, SF056_10_02=1, SF060_10_02=8297, SF061a_10_02=8306, SF061b_10_02=8125, SF055_10_03=1, SF056_10_03=1, SF060_10_03=8821, SF061a_10_03=8106, SF061b_10_03=8216, SF055_10_04=2, SF056_10_04=1, SF060_10_04=8667, SF061a_10_04=8317, SF061b_10_04=8136, SF055_10_05=2, SF056_10_05=1, SF060_10_05=8797, SF061a_10_05=8310, SF061b_10_05=8148, SF055_10_06=2, SF056_10_06=1, SF060_10_06=8760, SF061a_10_06=8242, SF061b_10_06=8043)>",
            "<SPARTN(SPARTN-1X-HPAC-GPS, msgType=1, nData=472, eaf=1, crcType=2, frameCrc=6, msgSubtype=0, timeTagtype=1, gnssTimeTag=451165680, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=33, authInd=1, embAuthLen=0, crc=8980777, SF005=152, SF068=1, SF069=0, SF030=9, SF031_01=30, SF039_01=0, SF040T_01=1, SF040I_01=1, SF041_01=1, SF042_01=2, SF043_01=130, SF044_01=1, SF048_01=210, SF049a_01=243, SF049b_01=249, SF054_01=1, SatBitmaskLen_01=0, SF011_01=880836610, SF055_01_01=1, SF056_01_01=1, SF060_01_01=8219, SF061a_01_01=8285, SF061b_01_01=8104, SF055_01_02=1, SF056_01_02=1, SF060_01_02=8246, SF061a_01_02=8293, SF061b_01_02=8119, SF055_01_03=4, SF056_01_03=1, SF060_01_03=8826, SF061a_01_03=8176, SF061b_01_03=8183, SF055_01_04=2, SF056_01_04=1, SF060_01_04=8628, SF061a_01_04=8292, SF061b_01_04=8132, SF055_01_05=2, SF056_01_05=1, SF060_01_05=8778, SF061a_01_05=8300, SF061b_01_05=8163, SF055_01_06=2, SF056_01_06=1, SF060_01_06=8627, SF061a_01_06=8246, SF061b_01_06=8029, SF031_02=31, SF039_02=0, SF040T_02=1, SF040I_02=1, SF041_02=1, SF042_02=1, SF043_02=130, SF044_02=1, SF048_02=206, SF049a_02=260, SF049b_02=255, SF054_02=1, SatBitmaskLen_02=0, SF011_02=880836610, SF055_02_01=2, SF056_02_01=1, SF060_02_01=8125, SF061a_02_01=8193, SF061b_02_01=8172, SF055_02_02=2, SF056_02_02=1, SF060_02_02=8181, SF061a_02_02=8204, SF061b_02_02=8197, SF055_02_03=2, SF056_02_03=1, SF060_02_03=8811, SF061a_02_03=8105, SF061b_02_03=8249, SF055_02_04=1, SF056_02_04=1, SF060_02_04=8595, SF061a_02_04=8229, SF061b_02_04=8238, SF055_02_05=2, SF056_02_05=1, SF060_02_05=8760, SF061a_02_05=8245, SF061b_02_05=8252, SF055_02_06=2, SF056_02_06=1, SF060_02_06=8452, SF061a_02_06=8171, SF061b_02_06=8110, SF031_03=32, SF039_03=0, SF040T_03=1, SF040I_03=1, SF041_03=1, SF042_03=3, SF043_03=131, SF044_03=1, SF048_03=208, SF049a_03=218, SF049b_03=249, SF054_03=1, SatBitmaskLen_03=0, SF011_03=880836610, SF055_03_01=1, SF056_03_01=1, SF060_03_01=8093, SF061a_03_01=8176, SF061b_03_01=8171, SF055_03_02=1, SF056_03_02=1, SF060_03_02=8174, SF061a_03_02=8211, SF061b_03_02=8189, SF055_03_03=1, SF056_03_03=1, SF060_03_03=8887, SF061a_03_03=8126, SF061b_03_03=8214, SF055_03_04=1, SF056_03_04=1, SF060_03_04=8660, SF061a_03_04=8215, SF061b_03_04=8230, SF055_03_05=2, SF056_03_05=1, SF060_03_05=8868, SF061a_03_05=8206, SF061b_03_05=8290, SF055_03_06=1, SF056_03_06=1, SF060_03_06=8338, SF061a_03_06=8121, SF061b_03_06=8112, SF031_04=33, SF039_04=0, SF040T_04=1, SF040I_04=1, SF041_04=1, SF042_04=3, SF043_04=131, SF044_04=1, SF048_04=223, SF049a_04=242, SF049b_04=255, SF054_04=1, SatBitmaskLen_04=0, SF011_04=880836608, SF055_04_01=1, SF056_04_01=1, SF060_04_01=8469, SF061a_04_01=8229, SF061b_04_01=8019, SF055_04_02=1, SF056_04_02=1, SF060_04_02=8347, SF061a_04_02=8259, SF061b_04_02=8086, SF055_04_03=2, SF056_04_03=1, SF060_04_03=8816, SF061a_04_03=8123, SF061b_04_03=8174, SF055_04_04=3, SF056_04_04=1, SF060_04_04=8581, SF061a_04_04=8274, SF061b_04_04=8143, SF055_04_05=2, SF056_04_05=1, SF060_04_05=8616, SF061a_04_05=8299, SF061b_04_05=8159, SF031_05=34, SF039_05=0, SF040T_05=1, SF040I_05=1, SF041_05=1, SF042_05=3, SF043_05=131, SF044_05=1, SF048_05=219, SF049a_05=233, SF049b_05=269, SF054_05=1, SatBitmaskLen_05=0, SF011_05=880836610, SF055_05_01=2, SF056_05_01=1, SF060_05_01=8305, SF061a_05_01=8252, SF061b_05_01=8078, SF055_05_02=1, SF056_05_02=1, SF060_05_02=8254, SF061a_05_02=8264, SF061b_05_02=8121, SF055_05_03=3, SF056_05_03=1, SF060_05_03=8815, SF061a_05_03=8112, SF061b_05_03=8179, SF055_05_04=3, SF056_05_04=1, SF060_05_04=8572, SF061a_05_04=8250, SF061b_05_04=8173, SF055_05_05=3, SF056_05_05=1, SF060_05_05=8635, SF061a_05_05=8296, SF061b_05_05=8189, SF055_05_06=2, SF056_05_06=1, SF060_05_06=8945, SF061a_05_06=8240, SF061b_05_06=7980, SF031_06=35, SF039_06=0, SF040T_06=1, SF040I_06=1, SF041_06=1, SF042_06=3, SF043_06=131, SF044_06=1, SF048_06=212, SF049a_06=258, SF049b_06=261, SF054_06=1, SatBitmaskLen_06=0, SF011_06=880836610, SF055_06_01=1, SF056_06_01=1, SF060_06_01=8142, SF061a_06_01=8283, SF061b_06_01=8119, SF055_06_02=1, SF056_06_02=1, SF060_06_02=8172, SF061a_06_02=8281, SF061b_06_02=8136, SF055_06_03=4, SF056_06_03=1, SF060_06_03=8820, SF061a_06_03=8162, SF061b_06_03=8155, SF055_06_04=1, SF056_06_04=1, SF060_06_04=8572, SF061a_06_04=8229, SF061b_06_04=8157, SF055_06_05=1, SF056_06_05=1, SF060_06_05=8728, SF061a_06_05=8226, SF061b_06_05=8177, SF055_06_06=2, SF056_06_06=1, SF060_06_06=8539, SF061a_06_06=8284, SF061b_06_06=8041, SF031_07=36, SF039_07=0, SF040T_07=1, SF040I_07=1, SF041_07=1, SF042_07=4, SF043_07=131, SF044_07=1, SF048_07=217, SF049a_07=210, SF049b_07=240, SF054_07=1, SatBitmaskLen_07=0, SF011_07=880836610, SF055_07_01=2, SF056_07_01=1, SF060_07_01=8245, SF061a_07_01=8045, SF061b_07_01=8171, SF055_07_02=1, SF056_07_02=1, SF060_07_02=8301, SF061a_07_02=8053, SF061b_07_02=8188, SF055_07_03=5, SF056_07_03=1, SF060_07_03=9007, SF061a_07_03=7991, SF061b_07_03=8248, SF055_07_04=4, SF056_07_04=1, SF060_07_04=8744, SF061a_07_04=7976, SF061b_07_04=8237, SF055_07_05=3, SF056_07_05=1, SF060_07_05=8910, SF061a_07_05=7974, SF061b_07_05=8262, SF055_07_06=1, SF056_07_06=1, SF060_07_06=8553, SF061a_07_06=8021, SF061b_07_06=8125, SF031_08=37, SF039_08=0, SF040T_08=1, SF040I_08=1, SF041_08=1, SF042_08=1, SF043_08=131, SF044_08=1, SF048_08=213, SF049a_08=245, SF049b_08=264, SF054_08=1, SatBitmaskLen_08=0, SF011_08=880836610, SF055_08_01=1, SF056_08_01=1, SF060_08_01=8218, SF061a_08_01=8027, SF061b_08_01=8154, SF055_08_02=1, SF056_08_02=1, SF060_08_02=8288, SF061a_08_02=8052, SF061b_08_02=8173, SF055_08_03=4, SF056_08_03=1, SF060_08_03=9048, SF061a_08_03=7904, SF061b_08_03=8190, SF055_08_04=1, SF056_08_04=1, SF060_08_04=8773, SF061a_08_04=8001, SF061b_08_04=8211, SF055_08_05=1, SF056_08_05=1, SF060_08_05=8974, SF061a_08_05=8012, SF061b_08_05=8257, SF055_08_06=1, SF056_08_06=1, SF060_08_06=8480, SF061a_08_06=8001, SF061b_08_06=8105, SF031_09=38, SF039_09=0, SF040T_09=1, SF040I_09=1, SF041_09=1, SF042_09=2, SF043_09=131, SF044_09=1, SF048_09=216, SF049a_09=256, SF049b_09=254, SF054_09=1, SatBitmaskLen_09=0, SF011_09=880836610, SF055_09_01=2, SF056_09_01=1, SF060_09_01=8058, SF061a_09_01=8318, SF061b_09_01=8101, SF055_09_02=2, SF056_09_02=1, SF060_09_02=8099, SF061a_09_02=8295, SF061b_09_02=8128, SF055_09_03=5, SF056_09_03=1, SF060_09_03=8757, SF061a_09_03=8366, SF061b_09_03=8167, SF055_09_04=2, SF056_09_04=1, SF060_09_04=8580, SF061a_09_04=8128, SF061b_09_04=8153, SF055_09_05=2, SF056_09_05=1, SF060_09_05=8730, SF061a_09_05=8144, SF061b_09_05=8193, SF055_09_06=2, SF056_09_06=1, SF060_09_06=8433, SF061a_09_06=8329, SF061b_09_06=8047, SF031_10=39, SF039_10=0, SF040T_10=1, SF040I_10=1, SF041_10=1, SF042_10=4, SF043_10=131, SF044_10=1, SF048_10=219, SF049a_10=305, SF049b_10=217, SF054_10=1, SatBitmaskLen_10=0, SF011_10=880836610, SF055_10_01=1, SF056_10_01=1, SF060_10_01=8343, SF061a_10_01=8048, SF061b_10_01=8153, SF055_10_02=1, SF056_10_02=1, SF060_10_02=8408, SF061a_10_02=8025, SF061b_10_02=8162, SF055_10_03=1, SF056_10_03=1, SF060_10_03=9104, SF061a_10_03=8149, SF061b_10_03=8210, SF055_10_04=2, SF056_10_04=1, SF060_10_04=8968, SF061a_10_04=7790, SF061b_10_04=8211, SF055_10_05=2, SF056_10_05=1, SF060_10_05=9127, SF061a_10_05=7832, SF061b_10_05=8217, SF055_10_06=1, SF056_10_06=1, SF060_10_06=8654, SF061a_10_06=8043, SF061b_10_06=8112)>",
            "<SPARTN(SPARTN-1X-HPAC-GPS, msgType=1, nData=98, eaf=1, crcType=2, frameCrc=11, msgSubtype=0, timeTagtype=1, gnssTimeTag=451165680, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=34, authInd=1, embAuthLen=0, crc=7396141, SF005=152, SF068=1, SF069=0, SF030=1, SF031_01=40, SF039_01=0, SF040T_01=1, SF040I_01=1, SF041_01=1, SF042_01=2, SF043_01=130, SF044_01=1, SF048_01=211, SF049a_01=237, SF049b_01=257, SF054_01=1, SatBitmaskLen_01=0, SF011_01=880836610, SF055_01_01=1, SF056_01_01=1, SF060_01_01=7930, SF061a_01_01=8312, SF061b_01_01=8182, SF055_01_02=1, SF056_01_02=1, SF060_01_02=8034, SF061a_01_02=8342, SF061b_01_02=8198, SF055_01_03=3, SF056_01_03=1, SF060_01_03=8623, SF061a_01_03=8244, SF061b_01_03=8234, SF055_01_04=2, SF056_01_04=1, SF060_01_04=8582, SF061a_01_04=8439, SF061b_01_04=8257, SF055_01_05=1, SF056_01_05=1, SF060_01_05=8799, SF061a_01_05=8423, SF061b_01_05=8292, SF055_01_06=1, SF056_01_06=1, SF060_01_06=8158, SF061a_01_06=8293, SF061b_01_06=8134, SF031_02=41, SF039_02=0, SF040T_02=1, SF040I_02=1, SF041_02=1, SF042_02=1, SF043_02=129, SF044_02=1, SF048_02=208, SF049a_02=256, SF049b_02=258, SF054_02=1, SatBitmaskLen_02=0, SF011_02=880836610, SF055_02_01=1, SF056_02_01=1, SF060_02_01=7982, SF061a_02_01=8309, SF061b_02_01=8182, SF055_02_02=1, SF056_02_02=1, SF060_02_02=8101, SF061a_02_02=8333, SF061b_02_02=8198, SF055_02_03=4, SF056_02_03=1, SF060_02_03=8614, SF061a_02_03=8071, SF061b_02_03=8255, SF055_02_04=1, SF056_02_04=1, SF060_02_04=8703, SF061a_02_04=8445, SF061b_02_04=8245, SF055_02_05=4, SF056_02_05=1, SF060_02_05=8911, SF061a_02_05=8386, SF061b_02_05=8293, SF055_02_06=1, SF056_02_06=1, SF060_02_06=8198, SF061a_02_06=8306, SF061b_02_06=8133)>",
            "<SPARTN(SPARTN-1X-HPAC-GLO, msgType=1, nData=421, eaf=1, crcType=2, frameCrc=3, msgSubtype=1, timeTagtype=1, gnssTimeTag=451176462, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=57, authInd=1, embAuthLen=0, crc=15138586, SF005=152, SF068=1, SF069=0, SF030=9, SF031_01=0, SF039_01=0, SF040T_01=1, SF040I_01=1, SF041_01=1, SF042_01=1, SF043_01=127, SF044_01=1, SF048_01=202, SF049a_01=255, SF049b_01=256, SF054_01=1, SatBitmaskLen_01=0, SF012_01=2627632, SF055_01_01=3, SF056_01_01=1, SF060_01_01=7728, SF061a_01_01=8245, SF061b_01_01=8148, SF055_01_02=4, SF056_01_02=1, SF060_01_02=8298, SF061a_01_02=8161, SF061b_01_02=8223, SF055_01_03=3, SF056_01_03=1, SF060_01_03=8013, SF061a_01_03=8240, SF061b_01_03=8160, SF055_01_04=4, SF056_01_04=1, SF060_01_04=7698, SF061a_01_04=8051, SF061b_01_04=8143, SF055_01_05=4, SF056_01_05=1, SF060_01_05=8115, SF061a_01_05=8201, SF061b_01_05=8189, SF055_01_06=4, SF056_01_06=1, SF060_01_06=7809, SF061a_01_06=8072, SF061b_01_06=8182, SF031_02=1, SF039_02=0, SF040T_02=1, SF040I_02=1, SF041_02=1, SF042_02=1, SF043_02=127, SF044_02=1, SF048_02=202, SF049a_02=253, SF049b_02=255, SF054_02=1, SatBitmaskLen_02=0, SF012_02=2627632, SF055_02_01=1, SF056_02_01=1, SF060_02_01=7814, SF061a_02_01=7991, SF061b_02_01=8159, SF055_02_02=5, SF056_02_02=1, SF060_02_02=8285, SF061a_02_02=8175, SF061b_02_02=8200, SF055_02_03=4, SF056_02_03=1, SF060_02_03=8032, SF061a_02_03=8193, SF061b_02_03=8157, SF055_02_04=4, SF056_02_04=1, SF060_02_04=7927, SF061a_02_04=7863, SF061b_02_04=8121, SF055_02_05=3, SF056_02_05=1, SF060_02_05=8097, SF061a_02_05=8254, SF061b_02_05=8181, SF055_02_06=3, SF056_02_06=1, SF060_02_06=7888, SF061a_02_06=8100, SF061b_02_06=8184, SF031_03=2, SF039_03=0, SF040T_03=1, SF040I_03=1, SF041_03=1, SF042_03=1, SF043_03=127, SF044_03=1, SF048_03=201, SF049a_03=258, SF049b_03=254, SF054_03=1, SatBitmaskLen_03=0, SF012_03=2627632, SF055_03_01=3, SF056_03_01=1, SF060_03_01=7749, SF061a_03_01=7961, SF061b_03_01=8143, SF055_03_02=2, SF056_03_02=1, SF060_03_02=8346, SF061a_03_02=8174, SF061b_03_02=8237, SF055_03_03=2, SF056_03_03=1, SF060_03_03=7960, SF061a_03_03=8241, SF061b_03_03=8143, SF055_03_04=5, SF056_03_04=1, SF060_03_04=7833, SF061a_03_04=7851, SF061b_03_04=8135, SF055_03_05=2, SF056_03_05=1, SF060_03_05=8085, SF061a_03_05=8270, SF061b_03_05=8192, SF055_03_06=2, SF056_03_06=1, SF060_03_06=7876, SF061a_03_06=8063, SF061b_03_06=8180, SF031_04=3, SF039_04=0, SF040T_04=1, SF040I_04=1, SF041_04=1, SF042_04=1, SF043_04=127, SF044_04=1, SF048_04=203, SF049a_04=253, SF049b_04=255, SF054_04=1, SatBitmaskLen_04=0, SF012_04=2101280, SF055_04_01=2, SF056_04_01=1, SF060_04_01=7923, SF061a_04_01=8170, SF061b_04_01=8175, SF055_04_02=2, SF056_04_02=1, SF060_04_02=8107, SF061a_04_02=8103, SF061b_04_02=8183, SF055_04_03=3, SF056_04_03=1, SF060_04_03=8096, SF061a_04_03=8273, SF061b_04_03=8190, SF031_05=4, SF039_05=0, SF040T_05=1, SF040I_05=1, SF041_05=1, SF042_05=1, SF043_05=127, SF044_05=1, SF048_05=203, SF049a_05=252, SF049b_05=256, SF054_05=1, SatBitmaskLen_05=0, SF012_05=2103328, SF055_05_01=1, SF056_05_01=1, SF060_05_01=7871, SF061a_05_01=8194, SF061b_05_01=8179, SF055_05_02=3, SF056_05_02=1, SF060_05_02=8063, SF061a_05_02=8052, SF061b_05_02=8171, SF055_05_03=1, SF056_05_03=1, SF060_05_03=7945, SF061a_05_03=8228, SF061b_05_03=8149, SF055_05_04=3, SF056_05_04=1, SF060_05_04=8094, SF061a_05_04=8287, SF061b_05_04=8200, SF031_06=5, SF039_06=0, SF040T_06=1, SF040I_06=1, SF041_06=1, SF042_06=1, SF043_06=127, SF044_06=1, SF048_06=209, SF049a_06=248, SF049b_06=251, SF054_06=1, SatBitmaskLen_06=0, SF012_06=528432, SF055_06_01=2, SF056_06_01=1, SF060_06_01=8275, SF061a_06_01=8164, SF061b_06_01=8136, SF055_06_02=3, SF056_06_02=1, SF060_06_02=8306, SF061a_06_02=8116, SF061b_06_02=8162, SF055_06_03=4, SF056_06_03=1, SF060_06_03=8140, SF061a_06_03=8325, SF061b_06_03=8181, SF055_06_04=4, SF056_06_04=1, SF060_06_04=8018, SF061a_06_04=8228, SF061b_06_04=8243, SF031_07=6, SF039_07=0, SF040T_07=1, SF040I_07=1, SF041_07=1, SF042_07=1, SF043_07=128, SF044_07=1, SF048_07=206, SF049a_07=253, SF049b_07=257, SF054_07=1, SatBitmaskLen_07=0, SF012_07=528432, SF055_07_01=3, SF056_07_01=1, SF060_07_01=8338, SF061a_07_01=8254, SF061b_07_01=8241, SF055_07_02=4, SF056_07_02=1, SF060_07_02=8243, SF061a_07_02=8100, SF061b_07_02=8147, SF055_07_03=4, SF056_07_03=1, SF060_07_03=8109, SF061a_07_03=8337, SF061b_07_03=8177, SF055_07_04=4, SF056_07_04=1, SF060_07_04=8024, SF061a_07_04=8250, SF061b_07_04=8195, SF031_08=7, SF039_08=0, SF040T_08=1, SF040I_08=1, SF041_08=1, SF042_08=1, SF043_08=127, SF044_08=1, SF048_08=204, SF049a_08=250, SF049b_08=254, SF054_08=1, SatBitmaskLen_08=0, SF012_08=3676208, SF055_08_01=3, SF056_08_01=1, SF060_08_01=8042, SF061a_08_01=8151, SF061b_08_01=8143, SF055_08_02=3, SF056_08_02=1, SF060_08_02=7909, SF061a_08_02=8131, SF061b_08_02=8191, SF055_08_03=4, SF056_08_03=1, SF060_08_03=8564, SF061a_08_03=8125, SF061b_08_03=8242, SF055_08_04=2, SF056_08_04=1, SF060_08_04=8328, SF061a_08_04=8012, SF061b_08_04=8159, SF055_08_05=5, SF056_08_05=1, SF060_08_05=8138, SF061a_08_05=8078, SF061b_08_05=8156, SF055_08_06=1, SF056_08_06=1, SF060_08_06=8222, SF061a_08_06=8136, SF061b_08_06=8213, SF055_08_07=3, SF056_08_07=1, SF060_08_07=8172, SF061a_08_07=8085, SF061b_08_07=8208, SF031_09=8, SF039_09=0, SF040T_09=1, SF040I_09=1, SF041_09=1, SF042_09=1, SF043_09=128, SF044_09=1, SF048_09=219, SF049a_09=246, SF049b_09=249, SF054_09=1, SatBitmaskLen_09=0, SF012_09=3674160, SF055_09_01=3, SF056_09_01=1, SF060_09_01=8625, SF061a_09_01=7984, SF061b_09_01=8211, SF055_09_02=2, SF056_09_02=1, SF060_09_02=8231, SF061a_09_02=8083, SF061b_09_02=8274, SF055_09_03=3, SF056_09_03=1, SF060_09_03=8589, SF061a_09_03=8119, SF061b_09_03=8268, SF055_09_04=2, SF056_09_04=1, SF060_09_04=8876, SF061a_09_04=7964, SF061b_09_04=8233, SF055_09_05=1, SF056_09_05=1, SF060_09_05=8562, SF061a_09_05=8151, SF061b_09_05=8253, SF055_09_06=3, SF056_09_06=1, SF060_09_06=8412, SF061a_09_06=8097, SF061b_09_06=8256, SF031_10=9, SF039_10=0, SF040T_10=1, SF040I_10=1, SF041_10=1, SF042_10=2, SF043_10=128, SF044_10=1, SF048_10=208, SF049a_10=253, SF049b_10=252, SF054_10=1, SatBitmaskLen_10=0, SF012_10=3674160, SF055_10_01=2, SF056_10_01=1, SF060_10_01=8277, SF061a_10_01=8039, SF061b_10_01=8115, SF055_10_02=2, SF056_10_02=1, SF060_10_02=8023, SF061a_10_02=8090, SF061b_10_02=8165, SF055_10_03=3, SF056_10_03=1, SF060_10_03=8541, SF061a_10_03=8087, SF061b_10_03=8210, SF055_10_04=4, SF056_10_04=1, SF060_10_04=8604, SF061a_10_04=7991, SF061b_10_04=8129, SF055_10_05=2, SF056_10_05=1, SF060_10_05=8289, SF061a_10_05=8144, SF061b_10_05=8164, SF055_10_06=3, SF056_10_06=1, SF060_10_06=8272, SF061a_10_06=8033, SF061b_10_06=8183)>",
            "<SPARTN(SPARTN-1X-HPAC-GLO, msgType=1, nData=456, eaf=1, crcType=2, frameCrc=2, msgSubtype=1, timeTagtype=1, gnssTimeTag=451176462, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=58, authInd=1, embAuthLen=0, crc=14979022, SF005=152, SF068=1, SF069=0, SF030=9, SF031_01=10, SF039_01=0, SF040T_01=1, SF040I_01=1, SF041_01=1, SF042_01=1, SF043_01=128, SF044_01=1, SF048_01=207, SF049a_01=252, SF049b_01=255, SF054_01=1, SatBitmaskLen_01=0, SF012_01=3676208, SF055_01_01=3, SF056_01_01=1, SF060_01_01=8130, SF061a_01_01=8043, SF061b_01_01=8145, SF055_01_02=2, SF056_01_02=1, SF060_01_02=7958, SF061a_01_02=8115, SF061b_01_02=8203, SF055_01_03=3, SF056_01_03=1, SF060_01_03=8602, SF061a_01_03=8117, SF061b_01_03=8253, SF055_01_04=3, SF056_01_04=1, SF060_01_04=8468, SF061a_01_04=8018, SF061b_01_04=8143, SF055_01_05=5, SF056_01_05=1, SF060_01_05=8248, SF061a_01_05=8007, SF061b_01_05=8149, SF055_01_06=2, SF056_01_06=1, SF060_01_06=8231, SF061a_01_06=8192, SF061b_01_06=8205, SF055_01_07=4, SF056_01_07=1, SF060_01_07=8240, SF061a_01_07=8088, SF061b_01_07=8203, SF031_02=11, SF039_02=0, SF040T_02=1, SF040I_02=1, SF041_02=1, SF042_02=2, SF043_02=129, SF044_02=1, SF048_02=230, SF049a_02=250, SF049b_02=254, SF054_02=1, SatBitmaskLen_02=0, SF012_02=3670064, SF055_02_01=2, SF056_02_01=1, SF060_02_01=8787, SF061a_02_01=7971, SF061b_02_01=8213, SF055_02_02=2, SF056_02_02=1, SF060_02_02=8255, SF061a_02_02=8086, SF061b_02_02=8281, SF055_02_03=3, SF056_02_03=1, SF060_02_03=8589, SF061a_02_03=8114, SF061b_02_03=8290, SF055_02_04=2, SF056_02_04=1, SF060_02_04=8557, SF061a_02_04=8155, SF061b_02_04=8238, SF055_02_05=3, SF056_02_05=1, SF060_02_05=8442, SF061a_02_05=8086, SF061b_02_05=8274, SF031_03=12, SF039_03=0, SF040T_03=1, SF040I_03=1, SF041_03=1, SF042_03=2, SF043_03=129, SF044_03=1, SF048_03=228, SF049a_03=244, SF049b_03=254, SF054_03=1, SatBitmaskLen_03=0, SF012_03=3670064, SF055_03_01=4, SF056_03_01=1, SF060_03_01=8825, SF061a_03_01=7972, SF061b_03_01=8210, SF055_03_02=1, SF056_03_02=1, SF060_03_02=8379, SF061a_03_02=8101, SF061b_03_02=8275, SF055_03_03=1, SF056_03_03=1, SF060_03_03=8733, SF061a_03_03=8095, SF061b_03_03=8299, SF055_03_04=1, SF056_03_04=1, SF060_03_04=8631, SF061a_03_04=8171, SF061b_03_04=8246, SF055_03_05=1, SF056_03_05=1, SF060_03_05=8575, SF061a_03_05=8052, SF061b_03_05=8299, SF031_04=13, SF039_04=0, SF040T_04=1, SF040I_04=1, SF041_04=1, SF042_04=2, SF043_04=129, SF044_04=1, SF048_04=210, SF049a_04=249, SF049b_04=252, SF054_04=1, SatBitmaskLen_04=0, SF012_04=3674160, SF055_04_01=1, SF056_04_01=1, SF060_04_01=8486, SF061a_04_01=7970, SF061b_04_01=8099, SF055_04_02=2, SF056_04_02=1, SF060_04_02=8128, SF061a_04_02=8063, SF061b_04_02=8151, SF055_04_03=2, SF056_04_03=1, SF060_04_03=8569, SF061a_04_03=8116, SF061b_04_03=8207, SF055_04_04=5, SF056_04_04=1, SF060_04_04=8820, SF061a_04_04=7933, SF061b_04_04=8132, SF055_04_05=1, SF056_04_05=1, SF060_04_05=8349, SF061a_04_05=8150, SF061b_04_05=8159, SF055_04_06=1, SF056_04_06=1, SF060_04_06=8384, SF061a_04_06=8036, SF061b_04_06=8181, SF031_05=14, SF039_05=0, SF040T_05=1, SF040I_05=1, SF041_05=1, SF042_05=1, SF043_05=129, SF044_05=1, SF048_05=210, SF049a_05=250, SF049b_05=256, SF054_05=1, SatBitmaskLen_05=0, SF012_05=3674160, SF055_05_01=1, SF056_05_01=1, SF060_05_01=8392, SF061a_05_01=7980, SF061b_05_01=8108, SF055_05_02=1, SF056_05_02=1, SF060_05_02=8091, SF061a_05_02=8082, SF061b_05_02=8140, SF055_05_03=3, SF056_05_03=1, SF060_05_03=8610, SF061a_05_03=8116, SF061b_05_03=8228, SF055_05_04=1, SF056_05_04=1, SF060_05_04=8786, SF061a_05_04=7847, SF061b_05_04=8125, SF055_05_05=2, SF056_05_05=1, SF060_05_05=8310, SF061a_05_05=8160, SF061b_05_05=8148, SF055_05_06=3, SF056_05_06=1, SF060_05_06=8377, SF061a_05_06=8017, SF061b_05_06=8180, SF031_06=15, SF039_06=0, SF040T_06=1, SF040I_06=1, SF041_06=1, SF042_06=1, SF043_06=129, SF044_06=1, SF048_06=205, SF049a_06=252, SF049b_06=253, SF054_06=1, SatBitmaskLen_06=0, SF012_06=3674160, SF055_06_01=2, SF056_06_01=1, SF060_06_01=8317, SF061a_06_01=8068, SF061b_06_01=8161, SF055_06_02=2, SF056_06_02=1, SF060_06_02=8079, SF061a_06_02=8142, SF061b_06_02=8212, SF055_06_03=3, SF056_06_03=1, SF060_06_03=8681, SF061a_06_03=8171, SF061b_06_03=8282, SF055_06_04=4, SF056_06_04=1, SF060_06_04=8677, SF061a_06_04=8014, SF061b_06_04=8161, SF055_06_05=2, SF056_06_05=1, SF060_06_05=8300, SF061a_06_05=8227, SF061b_06_05=8209, SF055_06_06=2, SF056_06_06=1, SF060_06_06=8389, SF061a_06_06=8090, SF061b_06_06=8215, SF031_07=16, SF039_07=0, SF040T_07=1, SF040I_07=1, SF041_07=1, SF042_07=1, SF043_07=129, SF044_07=1, SF048_07=221, SF049a_07=267, SF049b_07=253, SF054_07=1, SatBitmaskLen_07=0, SF012_07=3670064, SF055_07_01=2, SF056_07_01=1, SF060_07_01=8827, SF061a_07_01=8055, SF061b_07_01=8071, SF055_07_02=1, SF056_07_02=1, SF060_07_02=8288, SF061a_07_02=8155, SF061b_07_02=8161, SF055_07_03=2, SF056_07_03=1, SF060_07_03=8626, SF061a_07_03=8190, SF061b_07_03=8177, SF055_07_04=1, SF056_07_04=1, SF060_07_04=8499, SF061a_07_04=8244, SF061b_07_04=8126, SF055_07_05=1, SF056_07_05=1, SF060_07_05=8503, SF061a_07_05=8104, SF061b_07_05=8193, SF031_08=17, SF039_08=0, SF040T_08=1, SF040I_08=1, SF041_08=1, SF042_08=1, SF043_08=129, SF044_08=1, SF048_08=214, SF049a_08=264, SF049b_08=249, SF054_08=1, SatBitmaskLen_08=0, SF012_08=3670064, SF055_08_01=2, SF056_08_01=1, SF060_08_01=8688, SF061a_08_01=8034, SF061b_08_01=8108, SF055_08_02=1, SF056_08_02=1, SF060_08_02=8246, SF061a_08_02=8159, SF061b_08_02=8154, SF055_08_03=2, SF056_08_03=1, SF060_08_03=8630, SF061a_08_03=8191, SF061b_08_03=8206, SF055_08_04=1, SF056_08_04=1, SF060_08_04=8422, SF061a_08_04=8235, SF061b_08_04=8136, SF055_08_05=1, SF056_08_05=1, SF060_08_05=8505, SF061a_08_05=8095, SF061b_08_05=8190, SF031_09=18, SF039_09=0, SF040T_09=1, SF040I_09=1, SF041_09=1, SF042_09=1, SF043_09=129, SF044_09=1, SF048_09=210, SF049a_09=245, SF049b_09=253, SF054_09=1, SatBitmaskLen_09=0, SF012_09=3670128, SF055_09_01=4, SF056_09_01=1, SF060_09_01=8752, SF061a_09_01=8099, SF061b_09_01=8101, SF055_09_02=3, SF056_09_02=1, SF060_09_02=8383, SF061a_09_02=8197, SF061b_09_02=8146, SF055_09_03=3, SF056_09_03=1, SF060_09_03=8836, SF061a_09_03=8227, SF061b_09_03=8207, SF055_09_04=3, SF056_09_04=1, SF060_09_04=9371, SF061a_09_04=8295, SF061b_09_04=8036, SF055_09_05=1, SF056_09_05=1, SF060_09_05=8557, SF061a_09_05=8320, SF061b_09_05=8133, SF055_09_06=4, SF056_09_06=1, SF060_09_06=8691, SF061a_09_06=8163, SF061b_09_06=8168, SF031_10=19, SF039_10=0, SF040T_10=1, SF040I_10=1, SF041_10=1, SF042_10=1, SF043_10=129, SF044_10=1, SF048_10=206, SF049a_10=255, SF049b_10=252, SF054_10=1, SatBitmaskLen_10=0, SF012_10=3674224, SF055_10_01=2, SF056_10_01=1, SF060_10_01=8375, SF061a_10_01=8104, SF061b_10_01=8151, SF055_10_02=1, SF056_10_02=1, SF060_10_02=8101, SF061a_10_02=8143, SF061b_10_02=8214, SF055_10_03=1, SF056_10_03=1, SF060_10_03=8661, SF061a_10_03=8224, SF061b_10_03=8280, SF055_10_04=3, SF056_10_04=1, SF060_10_04=8793, SF061a_10_04=7950, SF061b_10_04=8191, SF055_10_05=1, SF056_10_05=1, SF060_10_05=8978, SF061a_10_05=8314, SF061b_10_05=8169, SF055_10_06=1, SF056_10_06=1, SF060_10_06=8278, SF061a_10_06=8240, SF061b_10_06=8218, SF055_10_07=2, SF056_10_07=1, SF060_10_07=8447, SF061a_10_07=8074, SF061b_10_07=8231)>",
            "<SPARTN(SPARTN-1X-HPAC-GLO, msgType=1, nData=468, eaf=1, crcType=2, frameCrc=5, msgSubtype=1, timeTagtype=1, gnssTimeTag=451176462, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=59, authInd=1, embAuthLen=0, crc=11322474, SF005=152, SF068=1, SF069=0, SF030=9, SF031_01=20, SF039_01=0, SF040T_01=1, SF040I_01=1, SF041_01=1, SF042_01=3, SF043_01=130, SF044_01=1, SF048_01=216, SF049a_01=255, SF049b_01=255, SF054_01=1, SatBitmaskLen_01=0, SF012_01=3670128, SF055_01_01=1, SF056_01_01=1, SF060_01_01=8876, SF061a_01_01=8047, SF061b_01_01=8081, SF055_01_02=1, SF056_01_02=1, SF060_01_02=8293, SF061a_01_02=8179, SF061b_01_02=8159, SF055_01_03=1, SF056_01_03=1, SF060_01_03=8618, SF061a_01_03=8206, SF061b_01_03=8190, SF055_01_04=1, SF056_01_04=1, SF060_01_04=9627, SF061a_01_04=8182, SF061b_01_04=7973, SF055_01_05=1, SF056_01_05=1, SF060_01_05=8455, SF061a_01_05=8241, SF061b_01_05=8133, SF055_01_06=1, SF056_01_06=1, SF060_01_06=8545, SF061a_01_06=8121, SF061b_01_06=8200, SF031_02=21, SF039_02=0, SF040T_02=1, SF040I_02=1, SF041_02=1, SF042_02=3, SF043_02=130, SF044_02=1, SF048_02=213, SF049a_02=249, SF049b_02=244, SF054_02=1, SatBitmaskLen_02=0, SF012_02=3670128, SF055_02_01=1, SF056_02_01=1, SF060_02_01=8743, SF061a_02_01=8079, SF061b_02_01=8095, SF055_02_02=1, SF056_02_02=1, SF060_02_02=8251, SF061a_02_02=8178, SF061b_02_02=8150, SF055_02_03=1, SF056_02_03=1, SF060_02_03=8622, SF061a_02_03=8209, SF061b_02_03=8203, SF055_02_04=3, SF056_02_04=1, SF060_02_04=9364, SF061a_02_04=8202, SF061b_02_04=7989, SF055_02_05=1, SF056_02_05=1, SF060_02_05=8388, SF061a_02_05=8246, SF061b_02_05=8136, SF055_02_06=1, SF056_02_06=1, SF060_02_06=8545, SF061a_02_06=8120, SF061b_02_06=8179, SF031_03=22, SF039_03=0, SF040T_03=1, SF040I_03=1, SF041_03=1, SF042_03=2, SF043_03=130, SF044_03=1, SF048_03=211, SF049a_03=262, SF049b_03=252, SF054_03=1, SatBitmaskLen_03=0, SF012_03=3670128, SF055_03_01=1, SF056_03_01=1, SF060_03_01=8788, SF061a_03_01=8205, SF061b_03_01=8064, SF055_03_02=1, SF056_03_02=1, SF060_03_02=8363, SF061a_03_02=8281, SF061b_03_02=8134, SF055_03_03=2, SF056_03_03=1, SF060_03_03=8786, SF061a_03_03=8327, SF061b_03_03=8176, SF055_03_04=2, SF056_03_04=1, SF060_03_04=9339, SF061a_03_04=8321, SF061b_03_04=8035, SF055_03_05=1, SF056_03_05=1, SF060_03_05=8488, SF061a_03_05=8372, SF061b_03_05=8125, SF055_03_06=3, SF056_03_06=1, SF060_03_06=8694, SF061a_03_06=8204, SF061b_03_06=8159, SF031_04=23, SF039_04=0, SF040T_04=1, SF040I_04=1, SF041_04=1, SF042_04=3, SF043_04=130, SF044_04=1, SF048_04=206, SF049a_04=244, SF049b_04=250, SF054_04=1, SatBitmaskLen_04=0, SF012_04=3670112, SF055_04_01=1, SF056_04_01=1, SF060_04_01=8649, SF061a_04_01=8225, SF061b_04_01=8075, SF055_04_02=1, SF056_04_02=1, SF060_04_02=8303, SF061a_04_02=8279, SF061b_04_02=8148, SF055_04_03=1, SF056_04_03=1, SF060_04_03=8776, SF061a_04_03=8348, SF061b_04_03=8194, SF055_04_04=2, SF056_04_04=1, SF060_04_04=9165, SF061a_04_04=8287, SF061b_04_04=8050, SF055_04_05=1, SF056_04_05=1, SF060_04_05=8421, SF061a_04_05=8368, SF061b_04_05=8150, SF031_05=24, SF039_05=0, SF040T_05=1, SF040I_05=1, SF041_05=1, SF042_05=1, SF043_05=130, SF044_05=1, SF048_05=206, SF049a_05=252, SF049b_05=254, SF054_05=1, SatBitmaskLen_05=0, SF012_05=3670128, SF055_05_01=1, SF056_05_01=1, SF060_05_01=8423, SF061a_05_01=8146, SF061b_05_01=8105, SF055_05_02=1, SF056_05_02=1, SF060_05_02=8153, SF061a_05_02=8195, SF061b_05_02=8186, SF055_05_03=1, SF056_05_03=1, SF060_05_03=8690, SF061a_05_03=8258, SF061b_05_03=8266, SF055_05_04=2, SF056_05_04=1, SF060_05_04=8949, SF061a_05_04=8223, SF061b_05_04=8167, SF055_05_05=1, SF056_05_05=1, SF060_05_05=8277, SF061a_05_05=8267, SF061b_05_05=8199, SF055_05_06=1, SF056_05_06=1, SF060_05_06=8540, SF061a_05_06=8145, SF061b_05_06=8208, SF031_06=25, SF039_06=0, SF040T_06=1, SF040I_06=1, SF041_06=1, SF042_06=1, SF043_06=130, SF044_06=1, SF048_06=209, SF049a_06=249, SF049b_06=257, SF054_06=1, SatBitmaskLen_06=0, SF012_06=3672176, SF055_06_01=1, SF056_06_01=1, SF060_06_01=8347, SF061a_06_01=8179, SF061b_06_01=8117, SF055_06_02=1, SF056_06_02=1, SF060_06_02=8146, SF061a_06_02=8190, SF061b_06_02=8184, SF055_06_03=1, SF056_06_03=1, SF060_06_03=8751, SF061a_06_03=8306, SF061b_06_03=8255, SF055_06_04=1, SF056_06_04=1, SF060_06_04=8422, SF061a_06_04=8154, SF061b_06_04=8083, SF055_06_05=3, SF056_06_05=1, SF060_06_05=8960, SF061a_06_05=8194, SF061b_06_05=8237, SF055_06_06=1, SF056_06_06=1, SF060_06_06=8267, SF061a_06_06=8254, SF061b_06_06=8197, SF055_06_07=1, SF056_06_07=1, SF060_06_07=8564, SF061a_06_07=8140, SF061b_06_07=8203, SF031_07=26, SF039_07=0, SF040T_07=1, SF040I_07=1, SF041_07=1, SF042_07=3, SF043_07=131, SF044_07=1, SF048_07=212, SF049a_07=256, SF049b_07=248, SF054_07=1, SatBitmaskLen_07=0, SF012_07=3670128, SF055_07_01=2, SF056_07_01=1, SF060_07_01=8716, SF061a_07_01=8035, SF061b_07_01=8064, SF055_07_02=1, SF056_07_02=1, SF060_07_02=7935, SF061a_07_02=8160, SF061b_07_02=8153, SF055_07_03=2, SF056_07_03=1, SF060_07_03=8181, SF061a_07_03=8227, SF061b_07_03=8211, SF055_07_04=4, SF056_07_04=1, SF060_07_04=9548, SF061a_07_04=7872, SF061b_07_04=7999, SF055_07_05=2, SF056_07_05=1, SF060_07_05=8053, SF061a_07_05=8236, SF061b_07_05=8134, SF055_07_06=1, SF056_07_06=1, SF060_07_06=8212, SF061a_07_06=8104, SF061b_07_06=8199, SF031_08=27, SF039_08=0, SF040T_08=1, SF040I_08=1, SF041_08=1, SF042_08=2, SF043_08=131, SF044_08=1, SF048_08=207, SF049a_08=258, SF049b_08=260, SF054_08=1, SatBitmaskLen_08=0, SF012_08=3670128, SF055_08_01=3, SF056_08_01=1, SF060_08_01=9077, SF061a_08_01=8020, SF061b_08_01=8109, SF055_08_02=1, SF056_08_02=1, SF060_08_02=8414, SF061a_08_02=8118, SF061b_08_02=8200, SF055_08_03=2, SF056_08_03=1, SF060_08_03=8727, SF061a_08_03=8147, SF061b_08_03=8232, SF055_08_04=5, SF056_08_04=1, SF060_08_04=9767, SF061a_08_04=7763, SF061b_08_04=7989, SF055_08_05=1, SF056_08_05=1, SF060_08_05=8524, SF061a_08_05=8180, SF061b_08_05=8178, SF055_08_06=2, SF056_08_06=1, SF060_08_06=8717, SF061a_08_06=8045, SF061b_08_06=8229, SF031_09=28, SF039_09=0, SF040T_09=1, SF040I_09=1, SF041_09=1, SF042_09=2, SF043_09=130, SF044_09=1, SF048_09=208, SF049a_09=247, SF049b_09=257, SF054_09=1, SatBitmaskLen_09=0, SF012_09=3670128, SF055_09_01=1, SF056_09_01=1, SF060_09_01=9003, SF061a_09_01=8021, SF061b_09_01=8112, SF055_09_02=1, SF056_09_02=1, SF060_09_02=8418, SF061a_09_02=8115, SF061b_09_02=8199, SF055_09_03=2, SF056_09_03=1, SF060_09_03=8765, SF061a_09_03=8129, SF061b_09_03=8254, SF055_09_04=3, SF056_09_04=1, SF060_09_04=9627, SF061a_09_04=7896, SF061b_09_04=8029, SF055_09_05=1, SF056_09_05=1, SF060_09_05=8508, SF061a_09_05=8169, SF061b_09_05=8174, SF055_09_06=2, SF056_09_06=1, SF060_09_06=8750, SF061a_09_06=8043, SF061b_09_06=8252, SF031_10=29, SF039_10=0, SF040T_10=1, SF040I_10=1, SF041_10=1, SF042_10=4, SF043_10=130, SF044_10=1, SF048_10=208, SF049a_10=301, SF049b_10=257, SF054_10=1, SatBitmaskLen_10=0, SF012_10=3670128, SF055_10_01=3, SF056_10_01=1, SF060_10_01=8616, SF061a_10_01=8169, SF061b_10_01=8093, SF055_10_02=2, SF056_10_02=1, SF060_10_02=8124, SF061a_10_02=8241, SF061b_10_02=8178, SF055_10_03=4, SF056_10_03=1, SF060_10_03=8522, SF061a_10_03=8263, SF061b_10_03=8192, SF055_10_04=2, SF056_10_04=1, SF060_10_04=9174, SF061a_10_04=8063, SF061b_10_04=8094, SF055_10_05=1, SF056_10_05=1, SF060_10_05=8209, SF061a_10_05=8291, SF061b_10_05=8166, SF055_10_06=1, SF056_10_06=1, SF060_10_06=8488, SF061a_10_06=8169, SF061b_10_06=8208)>",
            "<SPARTN(SPARTN-1X-HPAC-GLO, msgType=1, nData=468, eaf=1, crcType=2, frameCrc=5, msgSubtype=1, timeTagtype=1, gnssTimeTag=451176462, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=60, authInd=1, embAuthLen=0, crc=13756719, SF005=152, SF068=1, SF069=0, SF030=9, SF031_01=30, SF039_01=0, SF040T_01=1, SF040I_01=1, SF041_01=1, SF042_01=2, SF043_01=130, SF044_01=1, SF048_01=210, SF049a_01=243, SF049b_01=249, SF054_01=1, SatBitmaskLen_01=0, SF012_01=3670128, SF055_01_01=2, SF056_01_01=1, SF060_01_01=8525, SF061a_01_01=8191, SF061b_01_01=8086, SF055_01_02=2, SF056_01_02=1, SF060_01_02=8112, SF061a_01_02=8250, SF061b_01_02=8174, SF055_01_03=3, SF056_01_03=1, SF060_01_03=8536, SF061a_01_03=8267, SF061b_01_03=8206, SF055_01_04=4, SF056_01_04=1, SF060_01_04=9075, SF061a_01_04=7986, SF061b_01_04=8071, SF055_01_05=2, SF056_01_05=1, SF060_01_05=8191, SF061a_01_05=8277, SF061b_01_05=8162, SF055_01_06=1, SF056_01_06=1, SF060_01_06=8489, SF061a_01_06=8218, SF061b_01_06=8180, SF031_02=31, SF039_02=0, SF040T_02=1, SF040I_02=1, SF041_02=1, SF042_02=1, SF043_02=130, SF044_02=1, SF048_02=206, SF049a_02=260, SF049b_02=255, SF054_02=1, SatBitmaskLen_02=0, SF012_02=3672176, SF055_02_01=2, SF056_02_01=1, SF060_02_01=8462, SF061a_02_01=8186, SF061b_02_01=8114, SF055_02_02=2, SF056_02_02=1, SF060_02_02=8144, SF061a_02_02=8218, SF061b_02_02=8198, SF055_02_03=2, SF056_02_03=1, SF060_02_03=8619, SF061a_02_03=8295, SF061b_02_03=8261, SF055_02_04=3, SF056_02_04=1, SF060_02_04=8592, SF061a_02_04=8149, SF061b_02_04=8074, SF055_02_05=4, SF056_02_05=1, SF060_02_05=8977, SF061a_02_05=8102, SF061b_02_05=8114, SF055_02_06=2, SF056_02_06=1, SF060_02_06=8231, SF061a_02_06=8260, SF061b_02_06=8211, SF055_02_07=4, SF056_02_07=1, SF060_02_07=8550, SF061a_02_07=8157, SF061b_02_07=8232, SF031_03=32, SF039_03=0, SF040T_03=1, SF040I_03=1, SF041_03=1, SF042_03=3, SF043_03=131, SF044_03=1, SF048_03=208, SF049a_03=218, SF049b_03=249, SF054_03=1, SatBitmaskLen_03=0, SF012_03=3672176, SF055_03_01=1, SF056_03_01=1, SF060_03_01=8352, SF061a_03_01=8212, SF061b_03_01=8125, SF055_03_02=1, SF056_03_02=1, SF060_03_02=8139, SF061a_03_02=8197, SF061b_03_02=8178, SF055_03_03=2, SF056_03_03=1, SF060_03_03=8732, SF061a_03_03=8282, SF061b_03_03=8292, SF055_03_04=1, SF056_03_04=1, SF060_03_04=8429, SF061a_03_04=8212, SF061b_03_04=8087, SF055_03_05=5, SF056_03_05=1, SF060_03_05=8976, SF061a_03_05=8249, SF061b_03_05=8284, SF055_03_06=1, SF056_03_06=1, SF060_03_06=8240, SF061a_03_06=8270, SF061b_03_06=8202, SF055_03_07=3, SF056_03_07=1, SF060_03_07=8589, SF061a_03_07=8193, SF061b_03_07=8227, SF031_04=33, SF039_04=0, SF040T_04=1, SF040I_04=1, SF041_04=1, SF042_04=3, SF043_04=131, SF044_04=1, SF048_04=223, SF049a_04=242, SF049b_04=255, SF054_04=1, SatBitmaskLen_04=0, SF012_04=3670128, SF055_04_01=6, SF056_04_01=1, SF060_04_01=8788, SF061a_04_01=8164, SF061b_04_01=8069, SF055_04_02=2, SF056_04_02=1, SF060_04_02=7932, SF061a_04_02=8226, SF061b_04_02=8141, SF055_04_03=2, SF056_04_03=1, SF060_04_03=8118, SF061a_04_03=8288, SF061b_04_03=8203, SF055_04_04=5, SF056_04_04=1, SF060_04_04=10009, SF061a_04_04=7485, SF061b_04_04=8120, SF055_04_05=2, SF056_04_05=1, SF060_04_05=8000, SF061a_04_05=8258, SF061b_04_05=8149, SF055_04_06=4, SF056_04_06=1, SF060_04_06=8258, SF061a_04_06=8169, SF061b_04_06=8182, SF031_05=34, SF039_05=0, SF040T_05=1, SF040I_05=1, SF041_05=1, SF042_05=3, SF043_05=131, SF044_05=1, SF048_05=219, SF049a_05=233, SF049b_05=269, SF054_05=1, SatBitmaskLen_05=0, SF012_05=3670128, SF055_05_01=4, SF056_05_01=1, SF060_05_01=9195, SF061a_05_01=8079, SF061b_05_01=8077, SF055_05_02=4, SF056_05_02=1, SF060_05_02=8469, SF061a_05_02=8141, SF061b_05_02=8197, SF055_05_03=4, SF056_05_03=1, SF060_05_03=8754, SF061a_05_03=8173, SF061b_05_03=8246, SF055_05_04=6, SF056_05_04=1, SF060_05_04=10344, SF061a_05_04=7349, SF061b_05_04=7950, SF055_05_05=3, SF056_05_05=1, SF060_05_05=8538, SF061a_05_05=8163, SF061b_05_05=8189, SF055_05_06=4, SF056_05_06=1, SF060_05_06=8835, SF061a_05_06=8086, SF061b_05_06=8214, SF031_06=35, SF039_06=0, SF040T_06=1, SF040I_06=1, SF041_06=1, SF042_06=3, SF043_06=131, SF044_06=1, SF048_06=212, SF049a_06=258, SF049b_06=261, SF054_06=1, SatBitmaskLen_06=0, SF012_06=3670128, SF055_06_01=2, SF056_06_01=1, SF060_06_01=8476, SF061a_06_01=8263, SF061b_06_01=8100, SF055_06_02=2, SF056_06_02=1, SF060_06_02=8069, SF061a_06_02=8263, SF061b_06_02=8183, SF055_06_03=2, SF056_06_03=1, SF060_06_03=8503, SF061a_06_03=8251, SF061b_06_03=8221, SF055_06_04=5, SF056_06_04=1, SF060_06_04=9208, SF061a_06_04=7728, SF061b_06_04=8032, SF055_06_05=1, SF056_06_05=1, SF060_06_05=8141, SF061a_06_05=8256, SF061b_06_05=8186, SF055_06_06=5, SF056_06_06=1, SF060_06_06=8469, SF061a_06_06=8246, SF061b_06_06=8206, SF031_07=36, SF039_07=0, SF040T_07=1, SF040I_07=1, SF041_07=1, SF042_07=4, SF043_07=131, SF044_07=1, SF048_07=217, SF049a_07=210, SF049b_07=240, SF054_07=1, SatBitmaskLen_07=0, SF012_07=3670128, SF055_07_01=1, SF056_07_01=1, SF060_07_01=8610, SF061a_07_01=8099, SF061b_07_01=8077, SF055_07_02=1, SF056_07_02=1, SF060_07_02=8315, SF061a_07_02=8110, SF061b_07_02=8148, SF055_07_03=4, SF056_07_03=1, SF060_07_03=8802, SF061a_07_03=8086, SF061b_07_03=8220, SF055_07_04=4, SF056_07_04=1, SF060_07_04=9194, SF061a_07_04=7939, SF061b_07_04=8043, SF055_07_05=2, SF056_07_05=1, SF060_07_05=8390, SF061a_07_05=8102, SF061b_07_05=8164, SF055_07_06=1, SF056_07_06=1, SF060_07_06=8747, SF061a_07_06=8103, SF061b_07_06=8181, SF031_08=37, SF039_08=0, SF040T_08=1, SF040I_08=1, SF041_08=1, SF042_08=1, SF043_08=131, SF044_08=1, SF048_08=213, SF049a_08=245, SF049b_08=264, SF054_08=1, SatBitmaskLen_08=0, SF012_08=3670128, SF055_08_01=1, SF056_08_01=1, SF060_08_01=8506, SF061a_08_01=8106, SF061b_08_01=8093, SF055_08_02=1, SF056_08_02=1, SF060_08_02=8274, SF061a_08_02=8122, SF061b_08_02=8153, SF055_08_03=2, SF056_08_03=1, SF060_08_03=8836, SF061a_08_03=8140, SF061b_08_03=8235, SF055_08_04=2, SF056_08_04=1, SF060_08_04=9111, SF061a_08_04=8077, SF061b_08_04=8176, SF055_08_05=1, SF056_08_05=1, SF060_08_05=8365, SF061a_08_05=8135, SF061b_08_05=8171, SF055_08_06=2, SF056_08_06=1, SF060_08_06=8732, SF061a_08_06=8104, SF061b_08_06=8168, SF031_09=38, SF039_09=0, SF040T_09=1, SF040I_09=1, SF041_09=1, SF042_09=2, SF043_09=131, SF044_09=1, SF048_09=216, SF049a_09=256, SF049b_09=254, SF054_09=1, SatBitmaskLen_09=0, SF012_09=3670048, SF055_09_01=1, SF056_09_01=1, SF060_09_01=8389, SF061a_09_01=8303, SF061b_09_01=8113, SF055_09_02=4, SF056_09_02=1, SF060_09_02=8003, SF061a_09_02=8284, SF061b_09_02=8201, SF055_09_03=1, SF056_09_03=1, SF060_09_03=8470, SF061a_09_03=8237, SF061b_09_03=8212, SF055_09_04=3, SF056_09_04=1, SF060_09_04=8105, SF061a_09_04=8216, SF061b_09_04=8202, SF031_10=39, SF039_10=0, SF040T_10=1, SF040I_10=1, SF041_10=1, SF042_10=4, SF043_10=131, SF044_10=1, SF048_10=219, SF049a_10=305, SF049b_10=217, SF054_10=1, SatBitmaskLen_10=0, SF012_10=3670128, SF055_10_01=1, SF056_10_01=1, SF060_10_01=8635, SF061a_10_01=8163, SF061b_10_01=8120, SF055_10_02=1, SF056_10_02=1, SF060_10_02=8342, SF061a_10_02=8185, SF061b_10_02=8173, SF055_10_03=1, SF056_10_03=1, SF060_10_03=8896, SF061a_10_03=8060, SF061b_10_03=8229, SF055_10_04=2, SF056_10_04=1, SF060_10_04=9363, SF061a_10_04=7845, SF061b_10_04=7914, SF055_10_05=1, SF056_10_05=1, SF060_10_05=8452, SF061a_10_05=8103, SF061b_10_05=8183, SF055_10_06=1, SF056_10_06=1, SF060_10_06=8787, SF061a_10_06=8178, SF061b_10_06=8201)>",
            "<SPARTN(SPARTN-1X-HPAC-GLO, msgType=1, nData=61, eaf=1, crcType=2, frameCrc=15, msgSubtype=1, timeTagtype=1, gnssTimeTag=451176462, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=61, authInd=1, embAuthLen=0, crc=13417473, SF005=152, SF068=1, SF069=0, SF030=1, SF031_01=40, SF039_01=0, SF040T_01=1, SF040I_01=1, SF041_01=1, SF042_01=2, SF043_01=130, SF044_01=1, SF048_01=211, SF049a_01=237, SF049b_01=257, SF054_01=1, SatBitmaskLen_01=0, SF012_01=4144, SF055_01_01=5, SF056_01_01=1, SF060_01_01=8865, SF061a_01_01=7991, SF061b_01_01=8139, SF055_01_02=1, SF056_01_02=1, SF060_01_02=8345, SF061a_01_02=8283, SF061b_01_02=8182, SF055_01_03=2, SF056_01_03=1, SF060_01_03=8595, SF061a_01_03=8129, SF061b_01_03=8208, SF031_02=41, SF039_02=0, SF040T_02=1, SF040I_02=1, SF041_02=1, SF042_02=1, SF043_02=129, SF044_02=1, SF048_02=208, SF049a_02=256, SF049b_02=258, SF054_02=1, SatBitmaskLen_02=0, SF012_02=4144, SF055_02_01=5, SF056_02_01=1, SF060_02_01=8789, SF061a_02_01=8122, SF061b_02_01=8134, SF055_02_02=1, SF056_02_02=1, SF060_02_02=8383, SF061a_02_02=8286, SF061b_02_02=8179, SF055_02_03=2, SF056_02_03=1, SF060_02_03=8573, SF061a_02_03=8142, SF061b_02_03=8207)>",
        ]
        i = 0
        with open(os.path.join(self.dirname, "spartnHPAC.log"), "rb") as stream:
            spr = SPARTNReader(
                stream,
                quitonerror=ERRRAISE,
                decode=True,
                key=SPARTN_KEY,
                basedate=SPARTN_BASEDATE,
            )

            for raw, parsed in spr:
                if raw is not None:
                    # print(f'"{parsed}",')
                    self.assertEqual(str(parsed), EXPECTED_RESULT[i])
                    i += 1
        self.assertEqual(i, 10)

    def testGADLOG(
        self,
    ):  # test decoding of SPARTN GAD message
        EXPECTED_RESULT = [
            "<SPARTN(SPARTN-1X-GAD, msgType=2, nData=191, eaf=1, crcType=2, frameCrc=14, msgSubtype=0, timeTagtype=0, gnssTimeTag=28080, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=34, authInd=1, embAuthLen=0, crc=1303268, SF005=152, SF068=1, SF069=0, SF030=31, SF031_01=0, SF032_01=1613, SF033_01=1925, SF034_01=4, SF035_01=6, SF036_01=7, SF037_01=31, SF031_02=1, SF032_02=1582, SF033_02=1905, SF034_02=2, SF035_02=7, SF036_02=16, SF037_02=15, SF031_03=2, SF032_03=1583, SF033_03=2017, SF034_03=7, SF035_03=5, SF036_03=4, SF037_03=16, SF031_04=3, SF032_04=1552, SF033_04=1843, SF034_04=7, SF035_04=5, SF036_04=4, SF037_04=28, SF031_05=4, SF032_05=1549, SF033_05=1988, SF034_05=7, SF035_05=5, SF036_05=4, SF037_05=25, SF031_06=5, SF032_06=1518, SF033_06=1843, SF034_06=7, SF035_06=7, SF036_06=5, SF037_06=9, SF031_07=6, SF032_07=1518, SF033_07=1913, SF034_07=7, SF035_07=5, SF036_07=5, SF037_07=14, SF031_08=7, SF032_08=1515, SF033_08=1988, SF034_08=2, SF035_08=6, SF036_08=18, SF037_08=17, SF031_09=8, SF032_09=1496, SF033_09=1710, SF034_09=7, SF035_09=7, SF036_09=6, SF037_09=11, SF031_10=9, SF032_10=1477, SF033_10=1877, SF034_10=7, SF035_10=6, SF036_10=4, SF037_10=15, SF031_11=10, SF032_11=1479, SF033_11=1973, SF034_11=5, SF035_11=5, SF036_11=7, SF037_11=21, SF031_12=11, SF032_12=1448, SF033_12=1688, SF034_12=6, SF035_12=6, SF036_12=5, SF037_12=9, SF031_13=12, SF032_13=1448, SF033_13=1746, SF034_13=6, SF035_13=7, SF036_13=5, SF037_13=11, SF031_14=13, SF032_14=1445, SF033_14=1830, SF034_14=6, SF035_14=7, SF036_14=5, SF037_14=10, SF031_15=14, SF032_15=1443, SF033_15=1907, SF034_15=3, SF035_15=7, SF036_15=10, SF037_15=6, SF031_16=15, SF032_16=1443, SF033_16=1956, SF034_16=6, SF035_16=7, SF036_16=4, SF037_16=11, SF031_17=16, SF032_17=1413, SF033_17=1739, SF034_17=2, SF035_17=6, SF036_17=12, SF037_17=10, SF031_18=17, SF032_18=1413, SF033_18=1805, SF034_18=5, SF035_18=6, SF036_18=4, SF037_18=10, SF031_19=18, SF032_19=1411, SF033_19=1867, SF034_19=2, SF035_19=7, SF036_19=10, SF037_19=11, SF031_20=19, SF032_20=1415, SF033_20=1951, SF034_20=3, SF035_20=6, SF036_20=8, SF037_20=12, SF031_21=20, SF032_21=1391, SF033_21=1747, SF034_21=6, SF035_21=5, SF036_21=5, SF037_21=14, SF031_22=21, SF032_22=1391, SF033_22=1822, SF034_22=4, SF035_22=5, SF036_22=7, SF037_22=8, SF031_23=22, SF032_23=1391, SF033_23=1867, SF034_23=4, SF035_23=7, SF036_23=7, SF037_23=8, SF031_24=23, SF032_24=1390, SF033_24=1930, SF034_24=3, SF035_24=4, SF036_24=10, SF037_24=12, SF031_25=24, SF032_25=1389, SF033_25=1982, SF034_25=6, SF035_25=4, SF036_25=4, SF037_25=10, SF031_26=25, SF032_26=1374, SF033_26=2022, SF034_26=6, SF035_26=5, SF036_26=3, SF037_26=14, SF031_27=26, SF032_27=1343, SF033_27=1704, SF034_27=7, SF035_27=7, SF036_27=5, SF037_27=9, SF031_28=27, SF032_28=1357, SF033_28=1774, SF034_28=6, SF035_28=4, SF036_28=7, SF037_28=10, SF031_29=28, SF032_29=1360, SF033_29=1814, SF034_29=7, SF035_29=5, SF036_29=6, SF037_29=9, SF031_30=29, SF032_30=1360, SF033_30=1864, SF034_30=4, SF035_30=7, SF036_30=7, SF037_30=5, SF031_31=30, SF032_31=1360, SF033_31=1906, SF034_31=3, SF035_31=2, SF036_31=8, SF037_31=22, SF031_32=31, SF032_32=1361, SF033_32=1952, SF034_32=6, SF035_32=6, SF036_32=4, SF037_32=11)>",
            "<SPARTN(SPARTN-1X-GAD, msgType=2, nData=62, eaf=1, crcType=2, frameCrc=1, msgSubtype=0, timeTagtype=0, gnssTimeTag=28080, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=35, authInd=1, embAuthLen=0, crc=15938608, SF005=152, SF068=1, SF069=0, SF030=9, SF031_01=32, SF032_01=1352, SF033_01=2024, SF034_01=2, SF035_01=7, SF036_01=10, SF037_01=10, SF031_02=33, SF032_02=1303, SF033_02=1701, SF034_02=2, SF035_02=6, SF036_02=22, SF037_02=11, SF031_03=34, SF032_03=1312, SF033_03=1773, SF034_03=6, SF035_03=6, SF036_03=7, SF037_03=8, SF031_04=35, SF032_04=1334, SF033_04=1903, SF034_04=2, SF035_04=7, SF036_04=16, SF037_04=11, SF031_05=36, SF032_05=1332, SF033_05=1987, SF034_05=6, SF035_05=2, SF036_05=5, SF037_05=22, SF031_06=37, SF032_06=1332, SF033_06=2033, SF034_06=6, SF035_06=3, SF036_06=5, SF037_06=16, SF031_07=38, SF032_07=1302, SF033_07=1921, SF034_07=2, SF035_07=6, SF036_07=18, SF037_07=10, SF031_08=39, SF032_08=1297, SF033_08=1987, SF034_08=3, SF035_08=3, SF036_08=12, SF037_08=22, SF031_09=40, SF032_09=1398, SF033_09=2026, SF034_09=5, SF035_09=7, SF036_09=4, SF037_09=10, SF031_10=41, SF032_10=1420, SF033_10=2029, SF034_10=6, SF035_10=5, SF036_10=3, SF037_10=16)>",
            "<SPARTN(SPARTN-1X-GAD, msgType=2, nData=191, eaf=1, crcType=2, frameCrc=14, msgSubtype=0, timeTagtype=0, gnssTimeTag=28110, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=36, authInd=1, embAuthLen=0, crc=9218824, SF005=153, SF068=1, SF069=0, SF030=31, SF031_01=0, SF032_01=1613, SF033_01=1925, SF034_01=4, SF035_01=6, SF036_01=7, SF037_01=31, SF031_02=1, SF032_02=1582, SF033_02=1905, SF034_02=2, SF035_02=7, SF036_02=16, SF037_02=15, SF031_03=2, SF032_03=1583, SF033_03=2017, SF034_03=7, SF035_03=5, SF036_03=4, SF037_03=16, SF031_04=3, SF032_04=1552, SF033_04=1843, SF034_04=7, SF035_04=5, SF036_04=4, SF037_04=28, SF031_05=4, SF032_05=1549, SF033_05=1988, SF034_05=7, SF035_05=5, SF036_05=4, SF037_05=25, SF031_06=5, SF032_06=1518, SF033_06=1843, SF034_06=7, SF035_06=7, SF036_06=5, SF037_06=9, SF031_07=6, SF032_07=1518, SF033_07=1913, SF034_07=7, SF035_07=5, SF036_07=5, SF037_07=14, SF031_08=7, SF032_08=1515, SF033_08=1988, SF034_08=2, SF035_08=6, SF036_08=18, SF037_08=17, SF031_09=8, SF032_09=1496, SF033_09=1710, SF034_09=7, SF035_09=7, SF036_09=6, SF037_09=11, SF031_10=9, SF032_10=1477, SF033_10=1877, SF034_10=7, SF035_10=6, SF036_10=4, SF037_10=15, SF031_11=10, SF032_11=1479, SF033_11=1973, SF034_11=5, SF035_11=5, SF036_11=7, SF037_11=21, SF031_12=11, SF032_12=1448, SF033_12=1688, SF034_12=6, SF035_12=6, SF036_12=5, SF037_12=9, SF031_13=12, SF032_13=1448, SF033_13=1746, SF034_13=6, SF035_13=7, SF036_13=5, SF037_13=11, SF031_14=13, SF032_14=1445, SF033_14=1830, SF034_14=6, SF035_14=7, SF036_14=5, SF037_14=10, SF031_15=14, SF032_15=1443, SF033_15=1907, SF034_15=3, SF035_15=7, SF036_15=10, SF037_15=6, SF031_16=15, SF032_16=1443, SF033_16=1956, SF034_16=6, SF035_16=7, SF036_16=4, SF037_16=11, SF031_17=16, SF032_17=1413, SF033_17=1739, SF034_17=2, SF035_17=6, SF036_17=12, SF037_17=10, SF031_18=17, SF032_18=1413, SF033_18=1805, SF034_18=5, SF035_18=6, SF036_18=4, SF037_18=10, SF031_19=18, SF032_19=1411, SF033_19=1867, SF034_19=2, SF035_19=7, SF036_19=10, SF037_19=11, SF031_20=19, SF032_20=1415, SF033_20=1951, SF034_20=3, SF035_20=6, SF036_20=8, SF037_20=12, SF031_21=20, SF032_21=1391, SF033_21=1747, SF034_21=6, SF035_21=5, SF036_21=5, SF037_21=14, SF031_22=21, SF032_22=1391, SF033_22=1822, SF034_22=4, SF035_22=5, SF036_22=7, SF037_22=8, SF031_23=22, SF032_23=1391, SF033_23=1867, SF034_23=4, SF035_23=7, SF036_23=7, SF037_23=8, SF031_24=23, SF032_24=1390, SF033_24=1930, SF034_24=3, SF035_24=4, SF036_24=10, SF037_24=12, SF031_25=24, SF032_25=1389, SF033_25=1982, SF034_25=6, SF035_25=4, SF036_25=4, SF037_25=10, SF031_26=25, SF032_26=1374, SF033_26=2022, SF034_26=6, SF035_26=5, SF036_26=3, SF037_26=14, SF031_27=26, SF032_27=1343, SF033_27=1704, SF034_27=7, SF035_27=7, SF036_27=5, SF037_27=9, SF031_28=27, SF032_28=1357, SF033_28=1774, SF034_28=6, SF035_28=4, SF036_28=7, SF037_28=10, SF031_29=28, SF032_29=1360, SF033_29=1814, SF034_29=7, SF035_29=5, SF036_29=6, SF037_29=9, SF031_30=29, SF032_30=1360, SF033_30=1864, SF034_30=4, SF035_30=7, SF036_30=7, SF037_30=5, SF031_31=30, SF032_31=1360, SF033_31=1906, SF034_31=3, SF035_31=2, SF036_31=8, SF037_31=22, SF031_32=31, SF032_32=1361, SF033_32=1952, SF034_32=6, SF035_32=6, SF036_32=4, SF037_32=11)>",
            "<SPARTN(SPARTN-1X-GAD, msgType=2, nData=62, eaf=1, crcType=2, frameCrc=1, msgSubtype=0, timeTagtype=0, gnssTimeTag=28110, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=37, authInd=1, embAuthLen=0, crc=11512563, SF005=153, SF068=1, SF069=0, SF030=9, SF031_01=32, SF032_01=1352, SF033_01=2024, SF034_01=2, SF035_01=7, SF036_01=10, SF037_01=10, SF031_02=33, SF032_02=1303, SF033_02=1701, SF034_02=2, SF035_02=6, SF036_02=22, SF037_02=11, SF031_03=34, SF032_03=1312, SF033_03=1773, SF034_03=6, SF035_03=6, SF036_03=7, SF037_03=8, SF031_04=35, SF032_04=1334, SF033_04=1903, SF034_04=2, SF035_04=7, SF036_04=16, SF037_04=11, SF031_05=36, SF032_05=1332, SF033_05=1987, SF034_05=6, SF035_05=2, SF036_05=5, SF037_05=22, SF031_06=37, SF032_06=1332, SF033_06=2033, SF034_06=6, SF035_06=3, SF036_06=5, SF037_06=16, SF031_07=38, SF032_07=1302, SF033_07=1921, SF034_07=2, SF035_07=6, SF036_07=18, SF037_07=10, SF031_08=39, SF032_08=1297, SF033_08=1987, SF034_08=3, SF035_08=3, SF036_08=12, SF037_08=22, SF031_09=40, SF032_09=1398, SF033_09=2026, SF034_09=5, SF035_09=7, SF036_09=4, SF037_09=10, SF031_10=41, SF032_10=1420, SF033_10=2029, SF034_10=6, SF035_10=5, SF036_10=3, SF037_10=16)>",
        ]
        i = 0
        with open(os.path.join(self.dirname, "spartnGAD.log"), "rb") as stream:
            spr = SPARTNReader(
                stream,
                quitonerror=ERRRAISE,
                decode=True,
                key=SPARTN_KEY,
                basedate=SPARTN_BASEDATE,
            )

            for raw, parsed in spr:
                if raw is not None:
                    # print(f'"{parsed}",')
                    self.assertEqual(str(parsed), EXPECTED_RESULT[i])
                    i += 1
        self.assertEqual(i, 4)

    def testOCBLOG(
        self,
    ):  # test decoding of SPARTN OCB GPS message
        EXPECTED_RESULT = (
            "<SPARTN(SPARTN-1X-OCB-GPS, msgType=0, nData=30, eaf=1, crcType=2, frameCrc=12, msgSubtype=0, timeTagtype=0, gnssTimeTag=28075, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=37, authInd=1, embAuthLen=0, crc=4342523, SF005=151, SF010=0, SF069=0, SF008=0, SF009=0, SF016=0, SatBitmaskLen=0, SF011=880836738, SF013_01=0, SF014O_01=0, SF014C_01=1, SF014B_01=0, SF015_01=7, SF022_01=7, SF020CK_01=10555, SF024_01=1, SF013_02=0, SF014O_02=0, SF014C_02=1, SF014B_02=0, SF015_02=7, SF022_02=7, SF020CK_02=9214, SF024_02=1, SF013_03=0, SF014O_03=0, SF014C_03=1, SF014B_03=0, SF015_03=7, SF022_03=7, SF020CK_03=9502, SF024_03=1, SF013_04=0, SF014O_04=0, SF014C_04=1, SF014B_04=0, SF015_04=7, SF022_04=7, SF020CK_04=9603, SF024_04=1, SF013_05=0, SF014O_05=0, SF014C_05=1, SF014B_05=0, SF015_05=7, SF022_05=7, SF020CK_05=7690, SF024_05=2, SF013_06=0, SF014O_06=0, SF014C_06=1, SF014B_06=0, SF015_06=7, SF022_06=7, SF020CK_06=9996, SF024_06=1, SF013_07=0, SF014O_07=0, SF014C_07=1, SF014B_07=0, SF015_07=7, SF022_07=7, SF020CK_07=7511, SF024_07=1)>",
            "<SPARTN(SPARTN-1X-OCB-GLO, msgType=0, nData=33, eaf=1, crcType=2, frameCrc=3, msgSubtype=1, timeTagtype=0, gnssTimeTag=38857, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=28, authInd=1, embAuthLen=0, crc=4143853, SF005=151, SF010=0, SF069=0, SF008=0, SF009=0, SF017=0, SatBitmaskLen=0, SF012=3676272, SF013_01=0, SF014O_01=0, SF014C_01=1, SF014B_01=0, SF015_01=7, SF022_01=7, SF020CK_01=8178, SF024_01=3, SF013_02=0, SF014O_02=0, SF014C_02=1, SF014B_02=0, SF015_02=7, SF022_02=7, SF020CK_02=9130, SF024_02=2, SF013_03=0, SF014O_03=0, SF014C_03=1, SF014B_03=0, SF015_03=7, SF022_03=7, SF020CK_03=9182, SF024_03=2, SF013_04=0, SF014O_04=0, SF014C_04=1, SF014B_04=0, SF015_04=7, SF022_04=7, SF020CK_04=9155, SF024_04=2, SF013_05=0, SF014O_05=0, SF014C_05=1, SF014B_05=0, SF015_05=7, SF022_05=7, SF020CK_05=9339, SF024_05=1, SF013_06=0, SF014O_06=0, SF014C_06=1, SF014B_06=0, SF015_06=7, SF022_06=7, SF020CK_06=7293, SF024_06=3, SF013_07=0, SF014O_07=0, SF014C_07=1, SF014B_07=0, SF015_07=7, SF022_07=7, SF020CK_07=7747, SF024_07=2, SF013_08=0, SF014O_08=0, SF014C_08=1, SF014B_08=0, SF015_08=7, SF022_08=7, SF020CK_08=11847, SF024_08=1)>",
            "<SPARTN(SPARTN-1X-OCB-BEI, msgType=0, nData=36, eaf=1, crcType=2, frameCrc=11, msgSubtype=3, timeTagtype=0, gnssTimeTag=28061, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=60, authInd=1, embAuthLen=0, crc=13197342, SF005=151, SF010=0, SF069=0, SF008=0, SF009=0, SF097=0, SatBitmaskLen=1, SF094=212025376, SF013_01=0, SF014O_01=0, SF014C_01=1, SF014B_01=0, SF015_01=7, SF022_01=7, SF020CK_01=9616, SF024_01=1, SF013_02=0, SF014O_02=0, SF014C_02=1, SF014B_02=0, SF015_02=7, SF022_02=7, SF020CK_02=9974, SF024_02=3, SF013_03=0, SF014O_03=0, SF014C_03=1, SF014B_03=0, SF015_03=7, SF022_03=7, SF020CK_03=11018, SF024_03=1, SF013_04=0, SF014O_04=0, SF014C_04=1, SF014B_04=0, SF015_04=7, SF022_04=7, SF020CK_04=8386, SF024_04=1, SF013_05=0, SF014O_05=0, SF014C_05=1, SF014B_05=0, SF015_05=7, SF022_05=7, SF020CK_05=7787, SF024_05=2, SF013_06=0, SF014O_06=0, SF014C_06=1, SF014B_06=0, SF015_06=7, SF022_06=7, SF020CK_06=6385, SF024_06=4, SF013_07=0, SF014O_07=0, SF014C_07=1, SF014B_07=0, SF015_07=7, SF022_07=7, SF020CK_07=7231, SF024_07=2, SF013_08=0, SF014O_08=0, SF014C_08=1, SF014B_08=0, SF015_08=7, SF022_08=7, SF020CK_08=4851, SF024_08=4)>",
            "<SPARTN(SPARTN-1X-OCB-GAL, msgType=0, nData=34, eaf=1, crcType=2, frameCrc=3, msgSubtype=2, timeTagtype=0, gnssTimeTag=28075, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=28, authInd=1, embAuthLen=0, crc=5329954, SF005=151, SF010=1, SF069=0, SF008=0, SF009=0, SF096=1, SatBitmaskLen=0, SF093=9405731848, SF013_01=0, SF014O_01=0, SF014C_01=1, SF014B_01=0, SF015_01=7, SF022_01=7, SF020CK_01=9726, SF024_01=1, SF013_02=0, SF014O_02=0, SF014C_02=1, SF014B_02=0, SF015_02=7, SF022_02=7, SF020CK_02=10053, SF024_02=1, SF013_03=0, SF014O_03=0, SF014C_03=1, SF014B_03=0, SF015_03=7, SF022_03=7, SF020CK_03=9166, SF024_03=1, SF013_04=0, SF014O_04=0, SF014C_04=1, SF014B_04=0, SF015_04=7, SF022_04=7, SF020CK_04=9075, SF024_04=1, SF013_05=0, SF014O_05=0, SF014C_05=1, SF014B_05=0, SF015_05=7, SF022_05=6, SF020CK_05=9762, SF024_05=1, SF013_06=0, SF014O_06=0, SF014C_06=1, SF014B_06=0, SF015_06=7, SF022_06=7, SF020CK_06=7294, SF024_06=1, SF013_07=0, SF014O_07=0, SF014C_07=1, SF014B_07=0, SF015_07=7, SF022_07=7, SF020CK_07=6740, SF024_07=1, SF013_08=0, SF014O_08=0, SF014C_08=1, SF014B_08=0, SF015_08=3, SF022_08=3, SF020CK_08=7248, SF024_08=1)>",
            "<SPARTN(SPARTN-1X-OCB-GPS, msgType=0, nData=180, eaf=1, crcType=2, frameCrc=9, msgSubtype=0, timeTagtype=1, gnssTimeTag=451165680, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=38, authInd=1, embAuthLen=0, crc=11341296, SF005=152, SF010=0, SF069=0, SF008=0, SF009=0, SF016=0, SatBitmaskLen=0, SF011=880836738, SF013_01=0, SF014O_01=1, SF014C_01=1, SF014B_01=1, SF015_01=7, SF018_01=47, SF020R_01=8204, SF020A_01=8490, SF020C_01=8350, SF022_01=7, SF020CK_01=10564, SF024_01=1, PhaseBiasBitmaskLen_01=0, SF025_01=60, SF023_01_01=1, SF015_01_01=7, SF020PB_01_01=8191, SF023_01_02=1, SF015_01_02=7, SF020PB_01_02=8365, SF023_01_03=1, SF015_01_03=7, SF020PB_01_03=8365, SF023_01_04=1, SF015_01_04=7, SF020PB_01_04=8518, CodeBiasBitmaskLen_01=0, SF027_01=60, SF029_01_01=923, SF029_01_02=1020, SF029_01_03=1025, SF029_01_04=914, SF013_02=0, SF014O_02=1, SF014C_02=1, SF014B_02=1, SF015_02=7, SF018_02=31, SF020R_02=7829, SF020A_02=8031, SF020C_02=8132, SF022_02=7, SF020CK_02=9216, SF024_02=1, PhaseBiasBitmaskLen_02=0, SF025_02=60, SF023_02_01=1, SF015_02_01=7, SF020PB_02_01=8191, SF023_02_02=1, SF015_02_02=7, SF020PB_02_02=8735, SF023_02_03=1, SF015_02_03=7, SF020PB_02_03=8735, SF023_02_04=1, SF015_02_04=7, SF020PB_02_04=8641, CodeBiasBitmaskLen_02=0, SF027_02=60, SF029_02_01=912, SF029_02_02=955, SF029_02_03=945, SF029_02_04=1009, SF013_03=0, SF014O_03=1, SF014C_03=1, SF014B_03=1, SF015_03=7, SF018_03=119, SF020R_03=8098, SF020A_03=8962, SF020C_03=8203, SF022_03=7, SF020CK_03=9496, SF024_03=1, PhaseBiasBitmaskLen_03=0, SF025_03=60, SF023_03_01=1, SF015_03_01=7, SF020PB_03_01=8191, SF023_03_02=1, SF015_03_02=7, SF020PB_03_02=8119, SF023_03_03=1, SF015_03_03=7, SF020PB_03_03=8119, SF023_03_04=1, SF015_03_04=7, SF020PB_03_04=8043, CodeBiasBitmaskLen_03=0, SF027_03=60, SF029_03_01=1039, SF029_03_02=1147, SF029_03_03=1159, SF029_03_04=1057, SF013_04=0, SF014O_04=1, SF014C_04=1, SF014B_04=1, SF015_04=7, SF018_04=27, SF020R_04=8201, SF020A_04=8213, SF020C_04=7836, SF022_04=7, SF020CK_04=9609, SF024_04=1, PhaseBiasBitmaskLen_04=0, SF025_04=60, SF023_04_01=1, SF015_04_01=7, SF020PB_04_01=8191, SF023_04_02=1, SF015_04_02=7, SF020PB_04_02=8157, SF023_04_03=1, SF015_04_03=7, SF020PB_04_03=8157, SF023_04_04=1, SF015_04_04=7, SF020PB_04_04=8230, CodeBiasBitmaskLen_04=0, SF027_04=60, SF029_04_01=1014, SF029_04_02=1076, SF029_04_03=1068, SF029_04_04=977, SF013_05=0, SF014O_05=1, SF014C_05=1, SF014B_05=1, SF015_05=7, SF018_05=93, SF020R_05=8085, SF020A_05=9009, SF020C_05=8562, SF022_05=7, SF020CK_05=7689, SF024_05=2, PhaseBiasBitmaskLen_05=0, SF025_05=56, SF023_05_01=1, SF015_05_01=7, SF020PB_05_01=8191, SF023_05_02=1, SF015_05_02=7, SF020PB_05_02=8254, SF023_05_03=1, SF015_05_03=7, SF020PB_05_03=8254, CodeBiasBitmaskLen_05=0, SF027_05=56, SF029_05_01=1004, SF029_05_02=958, SF029_05_03=955, SF013_06=0, SF014O_06=1, SF014C_06=1, SF014B_06=1, SF015_06=7, SF018_06=50, SF020R_06=8128, SF020A_06=6613, SF020C_06=8512, SF022_06=7, SF020CK_06=9976, SF024_06=1, PhaseBiasBitmaskLen_06=0, SF025_06=60, SF023_06_01=1, SF015_06_01=7, SF020PB_06_01=8191, SF023_06_02=1, SF015_06_02=7, SF020PB_06_02=8206, SF023_06_03=1, SF015_06_03=7, SF020PB_06_03=8206, SF023_06_04=1, SF015_06_04=7, SF020PB_06_04=8171, CodeBiasBitmaskLen_06=0, SF027_06=60, SF029_06_01=1016, SF029_06_02=1123, SF029_06_03=1126, SF029_06_04=1030, SF013_07=0, SF014O_07=1, SF014C_07=1, SF014B_07=1, SF015_07=7, SF018_07=51, SF020R_07=8207, SF020A_07=7788, SF020C_07=8338, SF022_07=7, SF020CK_07=7520, SF024_07=1, PhaseBiasBitmaskLen_07=0, SF025_07=56, SF023_07_01=1, SF015_07_01=7, SF020PB_07_01=8191, SF023_07_02=1, SF015_07_02=7, SF020PB_07_02=8204, SF023_07_03=1, SF015_07_03=7, SF020PB_07_03=8204, CodeBiasBitmaskLen_07=0, SF027_07=56, SF029_07_01=977, SF029_07_02=921, SF029_07_03=924)>",
            "<SPARTN(SPARTN-1X-OCB-GLO, msgType=0, nData=152, eaf=1, crcType=2, frameCrc=2, msgSubtype=1, timeTagtype=1, gnssTimeTag=451176462, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=29, authInd=1, embAuthLen=0, crc=1087652, SF005=152, SF010=0, SF069=0, SF008=0, SF009=0, SF017=0, SatBitmaskLen=0, SF012=3676272, SF013_01=0, SF014O_01=1, SF014C_01=1, SF014B_01=1, SF015_01=7, SF019_01=91, SF020R_01=7992, SF020A_01=8029, SF020C_01=8809, SF022_01=7, SF020CK_01=8191, SF024_01=3, PhaseBiasBitmaskLen_01=0, SF026_01=24, SF023_01_01=1, SF015_01_01=7, SF020PB_01_01=8191, SF023_01_02=1, SF015_01_02=7, SF020PB_01_02=8465, CodeBiasBitmaskLen_01=0, SF028_01=24, SF029_01_01=952, SF029_01_02=933, SF013_02=0, SF014O_02=1, SF014C_02=1, SF014B_02=1, SF015_02=7, SF019_02=91, SF020R_02=8062, SF020A_02=6972, SF020C_02=8286, SF022_02=7, SF020CK_02=9122, SF024_02=2, PhaseBiasBitmaskLen_02=0, SF026_02=24, SF023_02_01=1, SF015_02_01=7, SF020PB_02_01=8191, SF023_02_02=1, SF015_02_02=7, SF020PB_02_02=8355, CodeBiasBitmaskLen_02=0, SF028_02=24, SF029_02_01=969, SF029_02_02=937, SF013_03=0, SF014O_03=1, SF014C_03=1, SF014B_03=1, SF015_03=7, SF019_03=91, SF020R_03=8639, SF020A_03=9527, SF020C_03=7779, SF022_03=7, SF020CK_03=9176, SF024_03=2, PhaseBiasBitmaskLen_03=0, SF026_03=24, SF023_03_01=1, SF015_03_01=7, SF020PB_03_01=8191, SF023_03_02=1, SF015_03_02=7, SF020PB_03_02=8359, CodeBiasBitmaskLen_03=0, SF028_03=24, SF029_03_01=922, SF029_03_02=925, SF013_04=0, SF014O_04=1, SF014C_04=1, SF014B_04=1, SF015_04=7, SF019_04=91, SF020R_04=8505, SF020A_04=5909, SF020C_04=8715, SF022_04=7, SF020CK_04=9146, SF024_04=1, PhaseBiasBitmaskLen_04=0, SF026_04=24, SF023_04_01=1, SF015_04_01=7, SF020PB_04_01=8191, SF023_04_02=1, SF015_04_02=7, SF020PB_04_02=8368, CodeBiasBitmaskLen_04=0, SF028_04=24, SF029_04_01=960, SF029_04_02=996, SF013_05=0, SF014O_05=1, SF014C_05=1, SF014B_05=1, SF015_05=7, SF019_05=91, SF020R_05=8364, SF020A_05=8137, SF020C_05=8712, SF022_05=7, SF020CK_05=9335, SF024_05=1, PhaseBiasBitmaskLen_05=0, SF026_05=24, SF023_05_01=1, SF015_05_01=7, SF020PB_05_01=8191, SF023_05_02=1, SF015_05_02=7, SF020PB_05_02=8342, CodeBiasBitmaskLen_05=0, SF028_05=24, SF029_05_01=985, SF029_05_02=994, SF013_06=0, SF014O_06=1, SF014C_06=1, SF014B_06=1, SF015_06=7, SF019_06=91, SF020R_06=8277, SF020A_06=9041, SF020C_06=8584, SF022_06=7, SF020CK_06=7312, SF024_06=3, PhaseBiasBitmaskLen_06=0, SF026_06=24, SF023_06_01=1, SF015_06_01=7, SF020PB_06_01=8191, SF023_06_02=1, SF015_06_02=7, SF020PB_06_02=7775, CodeBiasBitmaskLen_06=0, SF028_06=24, SF029_06_01=1137, SF029_06_02=1165, SF013_07=0, SF014O_07=1, SF014C_07=1, SF014B_07=1, SF015_07=7, SF019_07=91, SF020R_07=8604, SF020A_07=8898, SF020C_07=8187, SF022_07=7, SF020CK_07=7726, SF024_07=1, PhaseBiasBitmaskLen_07=0, SF026_07=24, SF023_07_01=1, SF015_07_01=7, SF020PB_07_01=8191, SF023_07_02=1, SF015_07_02=7, SF020PB_07_02=8123, CodeBiasBitmaskLen_07=0, SF028_07=24, SF029_07_01=1040, SF029_07_02=1040, SF013_08=0, SF014O_08=1, SF014C_08=1, SF014B_08=1, SF015_08=7, SF019_08=91, SF020R_08=7916, SF020A_08=7810, SF020C_08=9313, SF022_08=7, SF020CK_08=11855, SF024_08=2, PhaseBiasBitmaskLen_08=0, SF026_08=24, SF023_08_01=1, SF015_08_01=7, SF020PB_08_01=8191, SF023_08_02=1, SF015_08_02=7, SF020PB_08_02=8289, CodeBiasBitmaskLen_08=0, SF028_08=24, SF029_08_01=1001, SF029_08_02=1097)>",
            "<SPARTN(SPARTN-1X-OCB-BEI, msgType=0, nData=220, eaf=1, crcType=2, frameCrc=0, msgSubtype=3, timeTagtype=1, gnssTimeTag=451165666, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=61, authInd=1, embAuthLen=0, crc=14343958, SF005=152, SF010=0, SF069=0, SF008=0, SF009=0, SF097=0, SatBitmaskLen=1, SF094=212025376, SF013_01=0, SF014O_01=1, SF014C_01=1, SF014B_01=1, SF015_01=7, SF100_01=95, SF020R_01=8210, SF020A_01=8346, SF020C_01=8121, SF022_01=7, SF020CK_01=9676, SF024_01=1, PhaseBiasBitmaskLen_01=0, SF103_01=232, SF023_01_01=1, SF015_01_01=7, SF020PB_01_01=8191, SF023_01_02=1, SF015_01_02=7, SF020PB_01_02=8425, SF023_01_03=1, SF015_01_03=7, SF020PB_01_03=8419, SF023_01_04=1, SF015_01_04=7, SF020PB_01_04=8191, CodeBiasBitmaskLen_01=0, SF106_01=232, SF029_01_01=954, SF029_01_02=884, SF029_01_03=884, SF029_01_04=954, SF013_02=0, SF014O_02=1, SF014C_02=1, SF014B_02=1, SF015_02=7, SF100_02=95, SF020R_02=8138, SF020A_02=8154, SF020C_02=8271, SF022_02=7, SF020CK_02=9976, SF024_02=3, PhaseBiasBitmaskLen_02=0, SF103_02=232, SF023_02_01=1, SF015_02_01=7, SF020PB_02_01=8191, SF023_02_02=1, SF015_02_02=7, SF020PB_02_02=8611, SF023_02_03=1, SF015_02_03=7, SF020PB_02_03=8601, SF023_02_04=1, SF015_02_04=7, SF020PB_02_04=8191, CodeBiasBitmaskLen_02=0, SF106_02=232, SF029_02_01=936, SF029_02_02=817, SF029_02_03=817, SF029_02_04=936, SF013_03=0, SF014O_03=1, SF014C_03=1, SF014B_03=1, SF015_03=7, SF100_03=95, SF020R_03=8213, SF020A_03=8014, SF020C_03=8344, SF022_03=7, SF020CK_03=10997, SF024_03=1, PhaseBiasBitmaskLen_03=0, SF103_03=232, SF023_03_01=1, SF015_03_01=7, SF020PB_03_01=8191, SF023_03_02=1, SF015_03_02=7, SF020PB_03_02=8273, SF023_03_03=1, SF015_03_03=7, SF020PB_03_03=8271, SF023_03_04=1, SF015_03_04=7, SF020PB_03_04=8191, CodeBiasBitmaskLen_03=0, SF106_03=232, SF029_03_01=1014, SF029_03_02=709, SF029_03_03=709, SF029_03_04=1014, SF013_04=0, SF014O_04=1, SF014C_04=1, SF014B_04=1, SF015_04=7, SF100_04=95, SF020R_04=8353, SF020A_04=7973, SF020C_04=8462, SF022_04=7, SF020CK_04=8399, SF024_04=1, PhaseBiasBitmaskLen_04=0, SF103_04=232, SF023_04_01=1, SF015_04_01=7, SF020PB_04_01=8191, SF023_04_02=1, SF015_04_02=7, SF020PB_04_02=8464, SF023_04_03=1, SF015_04_03=7, SF020PB_04_03=8457, SF023_04_04=1, SF015_04_04=7, SF020PB_04_04=8191, CodeBiasBitmaskLen_04=0, SF106_04=232, SF029_04_01=913, SF029_04_02=793, SF029_04_03=793, SF029_04_04=913, SF013_05=0, SF014O_05=1, SF014C_05=1, SF014B_05=1, SF015_05=7, SF100_05=95, SF020R_05=8185, SF020A_05=8147, SF020C_05=8208, SF022_05=7, SF020CK_05=7799, SF024_05=2, PhaseBiasBitmaskLen_05=0, SF103_05=232, SF023_05_01=1, SF015_05_01=7, SF020PB_05_01=8191, SF023_05_02=1, SF015_05_02=7, SF020PB_05_02=8169, SF023_05_03=1, SF015_05_03=7, SF020PB_05_03=8170, SF023_05_04=1, SF015_05_04=7, SF020PB_05_04=8191, CodeBiasBitmaskLen_05=0, SF106_05=232, SF029_05_01=1027, SF029_05_02=907, SF029_05_03=907, SF029_05_04=1027, SF013_06=0, SF014O_06=1, SF014C_06=1, SF014B_06=1, SF015_06=7, SF100_06=95, SF020R_06=8243, SF020A_06=8035, SF020C_06=8215, SF022_06=7, SF020CK_06=6388, SF024_06=4, PhaseBiasBitmaskLen_06=0, SF103_06=232, SF023_06_01=1, SF015_06_01=7, SF020PB_06_01=8191, SF023_06_02=1, SF015_06_02=7, SF020PB_06_02=8045, SF023_06_03=1, SF015_06_03=7, SF020PB_06_03=8049, SF023_06_04=1, SF015_06_04=7, SF020PB_06_04=8191, CodeBiasBitmaskLen_06=0, SF106_06=232, SF029_06_01=1054, SF029_06_02=1073, SF029_06_03=1073, SF029_06_04=1054, SF013_07=0, SF014O_07=1, SF014C_07=1, SF014B_07=1, SF015_07=7, SF100_07=95, SF020R_07=8164, SF020A_07=8181, SF020C_07=8177, SF022_07=7, SF020CK_07=7242, SF024_07=2, PhaseBiasBitmaskLen_07=0, SF103_07=232, SF023_07_01=1, SF015_07_01=7, SF020PB_07_01=8191, SF023_07_02=1, SF015_07_02=7, SF020PB_07_02=8536, SF023_07_03=1, SF015_07_03=7, SF020PB_07_03=8527, SF023_07_04=1, SF015_07_04=7, SF020PB_07_04=8191, CodeBiasBitmaskLen_07=0, SF106_07=232, SF029_07_01=975, SF029_07_02=1077, SF029_07_03=1077, SF029_07_04=975, SF013_08=0, SF014O_08=1, SF014C_08=1, SF014B_08=1, SF015_08=7, SF100_08=95, SF020R_08=8158, SF020A_08=8395, SF020C_08=8091, SF022_08=7, SF020CK_08=4882, SF024_08=3, PhaseBiasBitmaskLen_08=0, SF103_08=232, SF023_08_01=1, SF015_08_01=7, SF020PB_08_01=8191, SF023_08_02=1, SF015_08_02=7, SF020PB_08_02=8828, SF023_08_03=1, SF015_08_03=7, SF020PB_08_03=8812, SF023_08_04=1, SF015_08_04=7, SF020PB_08_04=8191, CodeBiasBitmaskLen_08=0, SF106_08=232, SF029_08_01=911, SF029_08_02=1408, SF029_08_03=1408, SF029_08_04=911)>",
            "<SPARTN(SPARTN-1X-OCB-GAL, msgType=0, nData=191, eaf=1, crcType=2, frameCrc=11, msgSubtype=2, timeTagtype=1, gnssTimeTag=451165680, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=29, authInd=1, embAuthLen=0, crc=5207238, SF005=152, SF010=1, SF069=0, SF008=0, SF009=0, SF096=1, SatBitmaskLen=0, SF093=9405731848, SF013_01=0, SF014O_01=1, SF014C_01=1, SF014B_01=1, SF015_01=7, SF099_01=56, SF020R_01=8326, SF020A_01=8020, SF020C_01=8135, SF022_01=7, SF020CK_01=9728, SF024_01=1, PhaseBiasBitmaskLen_01=0, SF102_01=224, SF023_01_01=1, SF015_01_01=7, SF020PB_01_01=8191, SF023_01_02=1, SF015_01_02=7, SF020PB_01_02=8781, SF023_01_03=1, SF015_01_03=7, SF020PB_01_03=8699, CodeBiasBitmaskLen_01=0, SF105_01=224, SF029_01_01=893, SF029_01_02=937, SF029_01_03=930, SF013_02=0, SF014O_02=1, SF014C_02=1, SF014B_02=1, SF015_02=7, SF099_02=58, SF020R_02=8252, SF020A_02=8236, SF020C_02=8171, SF022_02=7, SF020CK_02=10055, SF024_02=1, PhaseBiasBitmaskLen_02=0, SF102_02=224, SF023_02_01=1, SF015_02_01=7, SF020PB_02_01=8191, SF023_02_02=1, SF015_02_02=7, SF020PB_02_02=8677, SF023_02_03=1, SF015_02_03=7, SF020PB_02_03=8610, CodeBiasBitmaskLen_02=0, SF105_02=224, SF029_02_01=916, SF029_02_02=984, SF029_02_03=977, SF013_03=0, SF014O_03=1, SF014C_03=1, SF014B_03=1, SF015_03=7, SF099_03=58, SF020R_03=8253, SF020A_03=8037, SF020C_03=8335, SF022_03=7, SF020CK_03=9168, SF024_03=1, PhaseBiasBitmaskLen_03=0, SF102_03=224, SF023_03_01=1, SF015_03_01=7, SF020PB_03_01=8191, SF023_03_02=1, SF015_03_02=7, SF020PB_03_02=8712, SF023_03_03=1, SF015_03_03=7, SF020PB_03_03=8598, CodeBiasBitmaskLen_03=0, SF105_03=224, SF029_03_01=841, SF029_03_02=804, SF029_03_03=801, SF013_04=0, SF014O_04=1, SF014C_04=1, SF014B_04=1, SF015_04=7, SF099_04=58, SF020R_04=8179, SF020A_04=8239, SF020C_04=8221, SF022_04=7, SF020CK_04=9068, SF024_04=1, PhaseBiasBitmaskLen_04=0, SF102_04=224, SF023_04_01=1, SF015_04_01=7, SF020PB_04_01=8191, SF023_04_02=1, SF015_04_02=7, SF020PB_04_02=8384, SF023_04_03=1, SF015_04_03=7, SF020PB_04_03=8347, CodeBiasBitmaskLen_04=0, SF105_04=224, SF029_04_01=1002, SF029_04_02=1073, SF029_04_03=1068, SF013_05=0, SF014O_05=1, SF014C_05=1, SF014B_05=1, SF015_05=7, SF099_05=58, SF020R_05=8405, SF020A_05=7854, SF020C_05=8256, SF022_05=6, SF020CK_05=9756, SF024_05=1, PhaseBiasBitmaskLen_05=0, SF102_05=224, SF023_05_01=1, SF015_05_01=7, SF020PB_05_01=8191, SF023_05_02=1, SF015_05_02=7, SF020PB_05_02=8233, SF023_05_03=1, SF015_05_03=7, SF020PB_05_03=8209, CodeBiasBitmaskLen_05=0, SF105_05=224, SF029_05_01=1018, SF029_05_02=1095, SF029_05_03=1090, SF013_06=0, SF014O_06=1, SF014C_06=1, SF014B_06=1, SF015_06=7, SF099_06=58, SF020R_06=8253, SF020A_06=7894, SF020C_06=8633, SF022_06=7, SF020CK_06=7304, SF024_06=1, PhaseBiasBitmaskLen_06=0, SF102_06=224, SF023_06_01=1, SF015_06_01=7, SF020PB_06_01=8191, SF023_06_02=1, SF015_06_02=7, SF020PB_06_02=8338, SF023_06_03=1, SF015_06_03=7, SF020PB_06_03=8272, CodeBiasBitmaskLen_06=0, SF105_06=224, SF029_06_01=991, SF029_06_02=955, SF029_06_03=944, SF013_07=0, SF014O_07=1, SF014C_07=1, SF014B_07=1, SF015_07=7, SF099_07=58, SF020R_07=8107, SF020A_07=8015, SF020C_07=8226, SF022_07=7, SF020CK_07=6729, SF024_07=1, PhaseBiasBitmaskLen_07=0, SF102_07=224, SF023_07_01=1, SF015_07_01=7, SF020PB_07_01=8191, SF023_07_02=1, SF015_07_02=7, SF020PB_07_02=8167, SF023_07_03=1, SF015_07_03=7, SF020PB_07_03=8119, CodeBiasBitmaskLen_07=0, SF105_07=224, SF029_07_01=1054, SF029_07_02=1011, SF029_07_03=1006, SF013_08=0, SF014O_08=1, SF014C_08=1, SF014B_08=1, SF015_08=4, SF099_08=58, SF020R_08=8046, SF020A_08=8174, SF020C_08=8238, SF022_08=4, SF020CK_08=7235, SF024_08=1, PhaseBiasBitmaskLen_08=0, SF102_08=224, SF023_08_01=1, SF015_08_01=4, SF020PB_08_01=8191, SF023_08_02=1, SF015_08_02=4, SF020PB_08_02=8228, SF023_08_03=1, SF015_08_03=4, SF020PB_08_03=8172, CodeBiasBitmaskLen_08=0, SF105_08=224, SF029_08_01=1017, SF029_08_02=985, SF029_08_03=977)>",
            "<SPARTN(SPARTN-1X-OCB-GPS, msgType=0, nData=30, eaf=1, crcType=2, frameCrc=12, msgSubtype=0, timeTagtype=0, gnssTimeTag=28085, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=39, authInd=1, embAuthLen=0, crc=11321430, SF005=152, SF010=0, SF069=0, SF008=0, SF009=0, SF016=0, SatBitmaskLen=0, SF011=880836738, SF013_01=0, SF014O_01=0, SF014C_01=1, SF014B_01=0, SF015_01=7, SF022_01=7, SF020CK_01=10564, SF024_01=1, SF013_02=0, SF014O_02=0, SF014C_02=1, SF014B_02=0, SF015_02=7, SF022_02=7, SF020CK_02=9216, SF024_02=1, SF013_03=0, SF014O_03=0, SF014C_03=1, SF014B_03=0, SF015_03=7, SF022_03=7, SF020CK_03=9496, SF024_03=1, SF013_04=0, SF014O_04=0, SF014C_04=1, SF014B_04=0, SF015_04=7, SF022_04=7, SF020CK_04=9609, SF024_04=1, SF013_05=0, SF014O_05=0, SF014C_05=1, SF014B_05=0, SF015_05=7, SF022_05=7, SF020CK_05=7689, SF024_05=1, SF013_06=0, SF014O_06=0, SF014C_06=1, SF014B_06=0, SF015_06=7, SF022_06=7, SF020CK_06=9976, SF024_06=1, SF013_07=0, SF014O_07=0, SF014C_07=1, SF014B_07=0, SF015_07=7, SF022_07=7, SF020CK_07=7520, SF024_07=1)>",
            "<SPARTN(SPARTN-1X-OCB-GLO, msgType=0, nData=33, eaf=1, crcType=2, frameCrc=3, msgSubtype=1, timeTagtype=0, gnssTimeTag=38867, solutionId=5, solutionProcId=11, encryptionId=1, encryptionSeq=30, authInd=1, embAuthLen=0, crc=517021, SF005=152, SF010=0, SF069=0, SF008=0, SF009=0, SF017=0, SatBitmaskLen=0, SF012=3676272, SF013_01=0, SF014O_01=0, SF014C_01=1, SF014B_01=0, SF015_01=7, SF022_01=7, SF020CK_01=8191, SF024_01=2, SF013_02=0, SF014O_02=0, SF014C_02=1, SF014B_02=0, SF015_02=7, SF022_02=7, SF020CK_02=9122, SF024_02=1, SF013_03=0, SF014O_03=0, SF014C_03=1, SF014B_03=0, SF015_03=7, SF022_03=7, SF020CK_03=9176, SF024_03=2, SF013_04=0, SF014O_04=0, SF014C_04=1, SF014B_04=0, SF015_04=7, SF022_04=7, SF020CK_04=9146, SF024_04=1, SF013_05=0, SF014O_05=0, SF014C_05=1, SF014B_05=0, SF015_05=7, SF022_05=7, SF020CK_05=9335, SF024_05=1, SF013_06=0, SF014O_06=0, SF014C_06=1, SF014B_06=0, SF015_06=7, SF022_06=7, SF020CK_06=7312, SF024_06=3, SF013_07=0, SF014O_07=0, SF014C_07=1, SF014B_07=0, SF015_07=7, SF022_07=7, SF020CK_07=7726, SF024_07=2, SF013_08=0, SF014O_08=0, SF014C_08=1, SF014B_08=0, SF015_08=7, SF022_08=7, SF020CK_08=11855, SF024_08=2)>",
        )
        i = 0
        with open(os.path.join(self.dirname, "spartnOCB.log"), "rb") as stream:
            spr = SPARTNReader(
                stream,
                quitonerror=ERRRAISE,
                decode=True,
                key=SPARTN_KEY,
                basedate=SPARTN_BASEDATE,
            )

            for raw, parsed in spr:
                if raw is not None:
                    # print(f'"{parsed}",')
                    self.assertEqual(str(parsed), EXPECTED_RESULT[i])
                    i += 1
        self.assertEqual(i, 10)

    def testnullkeyread(
        self,
    ):  # test null decryption key
        EXPECTED_ERROR = "Key must be provided if decoding is enabled"
        with self.assertRaisesRegex(ParameterError, EXPECTED_ERROR):
            i = 0
            spr = SPARTNReader(
                self.streamSPARTN,
                quitonerror=ERRRAISE,
                decode=True,
                key=None,
            )
            for raw, parsed in spr:
                if raw is not None:
                    i += 1

    def testnullkeyparse(
        self,
    ):  # test null decryption key in parse method
        EXPECTED_ERROR = "Key must be provided if decoding is enabled"
        with self.assertRaisesRegex(ParameterError, EXPECTED_ERROR):
            spr = SPARTNReader.parse(
                self.streamSPARTN,
                decode=True,
                key=None,
            )

    def testdatastream(self):  # test serialize()
        spr = SPARTNReader(self.streamSPARTN)
        res = str(spr.datastream)
        # print(res[-17:])
        self.assertEqual(
            res[-17:],
            "spartn_mqtt.log'>",
        )


if __name__ == "__main__":
    # import sys;sys.argv = ['', 'Test.testName']
    unittest.main()
